@@ -37,7 +37,7 @@
 #include "parse.h"
 #include "utils.h"
 
-extern void macroCmd(char *descr, char *exec, cmdParams* params);	// from cmds.c
+extern int macroCmd(char *descr, char *exec, cmdParams* params);  // from cmds.c
 
 extern char tmp[MAXMAXLEN];
 extern GMainLoop *loop;
@@ -177,7 +177,7 @@ static void freeProxy(type_dp *proxy)
 
 static void freeProxies()
 {
-    logger("DBG", "freeProxies()");
+    logger(L_DBG, "freeProxies()");
     type_dp *tm;
 
     while (proxies != NULL) {
@@ -198,28 +198,28 @@ static void freeProxyByName(char *id)
             if (prev != NULL) {
                 prev->next = prox->next;
             } else {
-                logger("ERR", "[EX]: freeProxyByName(): Previous item absent for non-first element");
+                logger(L_ERR, "[EX]: freeProxyByName(): Previous item absent for non-first element");
                 return;
             }
         }
         freeProxy(prox);
     } else {
-        logger("ERR", "[EX]: freeProxyByName(): no such dbus connection");
+        logger(L_ERR, "[EX]: freeProxyByName(): no such dbus connection");
     }
 }
 
 static void addProxy(char *id,char *s, char *p, char *i, DBusGProxy *proxy)
 {
-    logger("DBG", "addProxy()");
+    logger(L_DBG, "addProxy()");
     if (id == NULL || proxy == NULL) {
         return;
     }
 
     if (findProxy(id,NULL) != NULL) {
-        logger("DBG", "addProxy(): proxy already exists");
+        logger(L_DBG, "addProxy(): proxy already exists");
         return;
     }
-    type_dp *tm = calloc(sizeof(type_dp),1);
+    type_dp *tm = (type_dp *) calloc(sizeof(type_dp),1);
 
     tm->id        = strdup(id);
     tm->service   = strdup(s);
@@ -228,7 +228,7 @@ static void addProxy(char *id,char *s, char *p, char *i, DBusGProxy *proxy)
 
     tm->proxy     = proxy;
     if (proxy == NULL) {
-        logger("DBG", "addProxy(): proxy is NULL");
+        logger(L_DBG, "addProxy(): proxy is NULL");
         return;
     }
 
@@ -243,12 +243,12 @@ static void addProxy(char *id,char *s, char *p, char *i, DBusGProxy *proxy)
 
 static char* addCb(char *id)
 {
-    logger("DBG", "addCb()");
+    logger(L_DBG, "addCb()");
     if (id == NULL) {
         return NULL;
     }
 
-    type_cb *tmp = calloc(sizeof(type_cb),1);
+    type_cb *tmp = (type_cb *) calloc(sizeof(type_cb),1);
     tmp->id      = strdup(id);
 
     // Insert in head
@@ -264,7 +264,7 @@ static char* addCb(char *id)
 
 static void freeCbs()
 {
-    logger("DBG", "freeCbs()");
+    logger(L_DBG, "freeCbs()");
     type_cb *tmp;
 
     while (callbacks != NULL) {
@@ -279,7 +279,7 @@ static void freeCbs()
 
 int dbusInit()
 {
-    //logger("DBG", "dbusInit");
+    //logger(L_DBG, "dbusInit");
 #ifdef USE_DBUS
     GError *error = NULL;
 
@@ -322,11 +322,11 @@ int dbusCommand(char* cmdString)
     gboolean retCode = TRUE;
 
     if (connection == NULL) {
-        logger("ERR", "[EX]: dbusCommand(): no connection");
+        logger(L_ERR, "[EX]: dbusCommand(): no connection");
         return EXIT_NOK;
     }
     if (cmdString == NULL) {
-        logger("ERR", "[EX]: dbusCommand(): no command");
+        logger(L_ERR, "[EX]: dbusCommand(): no command");
         return EXIT_NOK;
     }
     DEBUG2("[EX]: dbusCommand(): %s", cmdString)
@@ -338,7 +338,7 @@ int dbusCommand(char* cmdString)
 
         char * id   = strtok(NULL,",");
         if (strcmp(token,"connect") == 0) {
-            logger("DBG", "[EX]: dbusCommand(): connect");
+            logger(L_DBG, "[EX]: dbusCommand(): connect");
 
             char * serv = strtok(NULL,",");
             char * path = strtok(NULL,",");
@@ -352,19 +352,19 @@ int dbusCommand(char* cmdString)
                                      intf); 		// ex.: "org.freedesktop.DBus");
                 addProxy(id,serv,path,intf,proxy);	// proxy can be NULL here
                 if (proxy == NULL)  {
-                    logger("DBG", "[EX]: dbusCommand(): get NULL proxy");
+                    logger(L_DBG, "[EX]: dbusCommand(): get NULL proxy");
                 }
             } else {
-                logger("ERR", "[EX]: dbusCommand(): improper input id-service-path-interface");
+                logger(L_ERR, "[EX]: dbusCommand(): improper input id-service-path-interface");
             }
 
         } else if (strcmp(token,"close") == 0) {
-            logger("DBG", "[EX]: dbusCommand(): close");
+            logger(L_DBG, "[EX]: dbusCommand(): close");
 
             freeProxyByName(id);
 
         } else if (strcmp(token,"set") == 0) {
-            logger("DBG", "[EX]: dbusCommand(): set");
+            logger(L_DBG, "[EX]: dbusCommand(): set");
 
             type_dp *prox = findProxy(id,NULL);
 
@@ -374,11 +374,11 @@ int dbusCommand(char* cmdString)
             }
 
             if (prox->proxy == NULL) {
-                logger("DBG", "[EX]: dbusCommand(): recreate proxy");
+                logger(L_DBG, "[EX]: dbusCommand(): recreate proxy");
                 DBusGProxy  *proxy = dbus_g_proxy_new_for_name (connection,
                                      prox->service,prox->path,prox->interface);
                 if (proxy == NULL)  {
-                    logger("DBG", "[EX]: dbusCommand(): get NULL proxy");
+                    logger(L_DBG, "[EX]: dbusCommand(): get NULL proxy");
                 }
                 prox->proxy = proxy;
             }
@@ -437,7 +437,7 @@ int dbusCommand(char* cmdString)
             }
 
         } else if (strcmp(token,"get") == 0) {
-            logger("DBG", "[EX]: dbusCommand(): get");
+            logger(L_DBG, "[EX]: dbusCommand(): get");
 
             type_dp *prox = findProxy(id,NULL);
 
@@ -449,11 +449,11 @@ int dbusCommand(char* cmdString)
             char retVals[512];
 
             if (prox->proxy == NULL) {
-                logger("DBG", "[EX]: dbusCommand(): recreate proxy");
+                logger(L_DBG, "[EX]: dbusCommand(): recreate proxy");
                 DBusGProxy  *proxy = dbus_g_proxy_new_for_name (connection,
                                      prox->service,prox->path,prox->interface);
                 if (proxy == NULL)  {
-                    logger("DBG", "[EX]: dbusCommand(): get NULL proxy");
+                    logger(L_DBG, "[EX]: dbusCommand(): get NULL proxy");
                 }
                 prox->proxy = proxy;
             }
@@ -480,7 +480,7 @@ int dbusCommand(char* cmdString)
 
                         ret = setVar(var,retVals,strlen(retVals));
                         if (ret != EXIT_OK) {
-                            logger("DBG","[EX]: dbusCommand(): Fails in setVar() int");
+                            logger(L_DBG,"[EX]: dbusCommand(): Fails in setVar() int");
                         }
 
                     } else if (retType == TYPE_UINT) {
@@ -494,7 +494,7 @@ int dbusCommand(char* cmdString)
 
                         ret = setVar(var,retVals,strlen(retVals));
                         if (ret != EXIT_OK) {
-                            logger("DBG","[EX]: dbusCommand(): Fails in setVar() uint");
+                            logger(L_DBG,"[EX]: dbusCommand(): Fails in setVar() uint");
                         }
 
                     } else if (retType == TYPE_DOUBLE) {
@@ -507,7 +507,7 @@ int dbusCommand(char* cmdString)
 
                         ret = setVar(var,retVals,strlen(retVals));
                         if (ret != EXIT_OK) {
-                            logger("DBG","[EX]: dbusCommand(): Fails in setVar() double");
+                            logger(L_DBG,"[EX]: dbusCommand(): Fails in setVar() double");
                         }
 
                     } else if (retType == TYPE_BOOL) {
@@ -519,7 +519,7 @@ int dbusCommand(char* cmdString)
 
                         ret = setVar(var,retVals,strlen(retVals));
                         if (ret != EXIT_OK) {
-                            logger("DBG","[EX]: dbusCommand(): Fails in setVar() boolean");
+                            logger(L_DBG,"[EX]: dbusCommand(): Fails in setVar() boolean");
                         }
 
                     } else if (retType == TYPE_STRING) {
@@ -534,7 +534,7 @@ int dbusCommand(char* cmdString)
                         }
                         ret = setVar(var,retVals,strlen(retVals));
                         if (ret != EXIT_OK) {
-                            logger("DBG","[EX]: dbusCommand(): Fails in setVar() string");
+                            logger(L_DBG,"[EX]: dbusCommand(): Fails in setVar() string");
                         }
 
                         g_free(rc);
@@ -548,12 +548,12 @@ int dbusCommand(char* cmdString)
                         prox->proxy = NULL;
                     }
                 } else {
-                    logger("DBG", "[EX]: dbusCommand(): set with no output params");
+                    logger(L_DBG, "[EX]: dbusCommand(): set with no output params");
                 }
             }
 
         } else if (strcmp(token,"signal") == 0) {
-            logger("DBG", "[EX]: dbusCommand(): signal");
+            logger(L_DBG, "[EX]: dbusCommand(): signal");
 
             type_dp *prox = findProxy(id,NULL);
 
@@ -563,11 +563,11 @@ int dbusCommand(char* cmdString)
             }
 
             if (prox->proxy == NULL) {
-                logger("DBG", "[EX]: dbusCommand(): recreate proxy");
+                logger(L_DBG, "[EX]: dbusCommand(): recreate proxy");
                 DBusGProxy  *proxy = dbus_g_proxy_new_for_name (connection,
                                      prox->service,prox->path,prox->interface);
                 if (proxy == NULL)  {
-                    logger("DBG", "[EX]: dbusCommand(): get NULL proxy");
+                    logger(L_DBG, "[EX]: dbusCommand(): get NULL proxy");
                 }
                 prox->proxy = proxy;
             }
@@ -618,7 +618,7 @@ int dbusCommand(char* cmdString)
                         ERROR2("[EX]: dbusCommand(): unsupported param type %s",type);
                     }
                 } else {
-                    logger("DBG", "[EX]: dbusCommand(): set with no output params");
+                    logger(L_DBG, "[EX]: dbusCommand(): set with no output params");
                 }
             }
 
