@@ -41,7 +41,7 @@ extern char tmp[MAXMAXLEN];
 
 int useQuestionInCLCC = 0;
 
-void sendSyncCommand(char *bytes, char *answer, int size, char *expect)
+void sendSyncCommand(const char *bytes, char *answer, int size, char *expect)
 {
     DEBUG2("sendSyncCommand >%s<\n", bytes);
 
@@ -80,7 +80,7 @@ static int sendCKPD(char *key)
     char ckpd[MAXCKPDLEN];
 
     if (key == NULL || key[0] == '\0') {
-        logger("DBG","Empty symbol in sendCKPD()");
+        logger(L_DBG,"Empty symbol in sendCKPD()");
         return EXIT_NOK;
     }
     DEBUG2("sendCKPD >%s<", key);
@@ -115,7 +115,7 @@ static int sendCKPD(char *key)
         // Filter out button up
         char *ptr = strstr(answer, expect);
         if(ptr == NULL) {
-            logger("DBG","cant find button up event");
+            logger(L_DBG,"cant find button up event");
         } else {
             int z;
             int l = strlen(expect);
@@ -138,7 +138,7 @@ static int sendCKPD(char *key)
         strcat(expect, ",1");
         ptr = strstr(answer, expect);
         if(ptr == NULL) {
-            logger("DBG","cant find button down event");
+            logger(L_DBG,"cant find button down event");
         } else {
             int z;
             int l = strlen(expect);
@@ -189,7 +189,7 @@ int sendSeq(const char *seq)
     return EXIT_OK;
 }
 
-char *parse_CLCC(char *clcc)
+static const char *parse_CLCC(char *clcc)
 {
     // There are could be more than one call at time ... but here we will get then one-by-one
     // +CLCC: 1,,4,0,0,"<phone number here>",129,
@@ -237,13 +237,13 @@ int getClip(char* CallerID)
 
     answer[0] = '\0';
 
-    logger("DBG", "getClip()");
+    logger(L_DBG, "getClip()");
 
 
     // Some phones uses AT+CLCC?, some just AT+CLCC (Sagem, Siemens-S55, SE-K750)
 
     if (useQuestionInCLCC == 0) {
-        //logger("DBG", "getClip() send AT+CLCC");
+        //logger(L_DBG, "getClip() send AT+CLCC");
 
         strcpy(clcc,DEF_AT_CLCC);
         strcat(clcc,"\r");
@@ -256,7 +256,7 @@ int getClip(char* CallerID)
         } else if (strstr(answer,"OK") != NULL) {
             return EXIT_OK;
         } else if (strstr(answer,"ERR") != NULL) {
-            logger("WARNING", "Got ERROR on AT+CLCC. Will try AT+CLCC?");
+            logger(L_WARN, "Got ERROR on AT+CLCC. Will try AT+CLCC?");
             useQuestionInCLCC = 1;      // Ask phone again; but will never ask AT+CLCC more
         } else {
             tryAnyway = 1;              // Ask phone again; to be sure
@@ -267,7 +267,7 @@ int getClip(char* CallerID)
 
         tryAnyway = 0;
 
-        //logger("DBG", "getClip() send AT+CLCC?");
+        //logger(L_DBG, "getClip() send AT+CLCC?");
 
         strcpy(clcc,DEF_AT_CLCC);
         strcat(clcc,"?");
@@ -281,7 +281,7 @@ int getClip(char* CallerID)
         } else if (strstr(answer,"OK") != NULL) {
             return EXIT_OK;
         } else if (strstr(answer,"ERR") != NULL) {
-            logger("ERR", "Got ERROR on AT+CLCC?");
+            logger(L_ERR, "Got ERROR on AT+CLCC?");
             return EXIT_NOK;
         }
     }
