@@ -25,6 +25,6 @@
 int sendSeq 	(const char *string);
 int sendCMER	(int onOff);
 int getClip 	(char *string);
-void sendSyncCommand(char *bytes, char *answer, int size, char *expect);
+void sendSyncCommand(const char *bytes, char *answer, int size, char *expect);
 
 #endif
