@@ -59,8 +59,8 @@
 extern char tmp[MAXMAXLEN];
 extern gboolean stillRun;
 
-static int portfd       = 0;
-static int sportfd      = 0;
+static int portfd       = -1;
+static int sportfd      = -1;
 static int portflags    = 0;
 static int oldflags     = 0;
 static int rtscts       = 0;
@@ -82,9 +82,9 @@ int openSerialPort(char* port)
     /* get a file descriptor */
     if ((portfd = open(port, O_RDWR|O_NOCTTY|O_NDELAY/*|O_CLOEXEC fails to compile ? */)) < 0) {
         sprintf(tmp, "can not open %s", port);
-        logger("ERR", tmp);
+        logger(L_ERR, tmp);
         printf("ERROR: can not open %s\n", port);
-        portfd = 0;
+        portfd = -1;
         return -1;
     }
     fcntl(portfd,F_SETFD,FD_CLOEXEC);
@@ -140,11 +140,12 @@ int closeSerialPort(int final)
 {
     int retval = 0;
 
-    logger("INF", "closeSerialPort");
+    logger(L_INF, "closeSerialPort");
+    //printf("closeSerialPort (%d) (%d)\n", final, portfd);
 
-    if (!portfd) { /* already closed */
+    if (portfd < 0) { /* already closed */
         if (final) {
-            logger("INF", "Already closed ?");
+            logger(L_INF, "Already closed ?");
         }
         return -1;
     }
@@ -160,7 +161,7 @@ int closeSerialPort(int final)
         }
     }
     retval = close(portfd);
-    portfd = 0;
+    portfd = -1;
 
     return retval;
 }
@@ -183,9 +184,9 @@ int rfcommConnect(const char *addr, int channel)
     str2ba(addr, &(bt_addr.rc_bdaddr));
 
     if ((portfd = socket(AF_BLUETOOTH, SOCK_STREAM|SOCK_CLOEXEC, BTPROTO_RFCOMM)) < 0) {
-        logger("ERR", "opening socket");
+        logger(L_ERR, "opening socket");
         printf("ERROR: opening socket\n");
-
+        portfd = -1;
         return -1;
     }
 
@@ -231,7 +232,7 @@ static int bt_read_tmo(char* buf, int len, int timeout)
     if (ok > 0) {
         ok = read(portfd, buf, len);
         if (ok == 0) {
-            logger("DBG", "EOF during read()");
+            logger(L_DBG, "EOF during read()");
             return EOF;
         }
 
@@ -240,7 +241,7 @@ static int bt_read_tmo(char* buf, int len, int timeout)
         //	char buf2[1024];
         //	strncpy(buf2,buf,ok);
         //	sprintf(tmp, "READ: %s", buf2);
-        //	logger("DBG", tmp);
+        //	logger(L_DBG, tmp);
         //}
         //////////////////////////////////////
         return ok;
@@ -266,7 +267,7 @@ int  bt_readchar(char* c, int timeout)
     int rv =  bt_read_tmo(buf, 1, timeout);
     /*if (rv != 0) {
     	sprintf(tmp, "bt_read_tmo returns: %d", rv);
-    	logger("DBG", tmp);
+    	logger(L_DBG, tmp);
     }*/
 
     if (rv == 1) {
@@ -283,7 +284,7 @@ int  bt_readchar(char* c, int timeout)
 }
 
 // max should be >= 100
-int bt_put_command(char* command,
+int bt_put_command(const char* command,
                    char* answer,
                    int   max,
                    int   timeout,
@@ -299,14 +300,18 @@ int bt_put_command(char* command,
         return 0;
     }
 
-    logger("DBG",command);
+    logger(L_DBG,command);
     if (expect != NULL) {
-        logger("DBG",expect);
+        logger(L_DBG,expect);
     }
 
     // send command
     if (command && command[0]) {
-        write(portfd,command,strlen(command));
+        #ifdef __cplusplus
+        ssize_t dummy = 
+        #endif
+            write(portfd,command,strlen(command));
+	
         tcdrain(portfd);
     }
 
@@ -344,7 +349,7 @@ int bt_put_command(char* command,
                 if (expect && expect[0]) {
                     if (strstr(answer,expect)) {
                         sprintf(tmp, "Got expected %s (iteration %d)", answer, timeoutcounter);
-                        logger("DBG", tmp);
+                        logger(L_DBG, tmp);
                         found=1;
                     }
                 }
@@ -366,7 +371,7 @@ int bt_put_command(char* command,
         while (a2[0] == '\r' || a2[0] == '\n')  {
             a2++;
         }
-        logger("DBG",a2);
+        logger(L_DBG,a2);
     }
 
     return count;
@@ -465,16 +470,16 @@ int readStdin(char* buf, int max)
 int unix_open_port(char* port)
 {
     sprintf(tmp, "unix_open_port >%s<", port);
-    logger("INF", tmp);
+    logger(L_INF, tmp);
 
     struct sockaddr_un serveraddr;
 
     portfd = socket(AF_UNIX, SOCK_STREAM|SOCK_CLOEXEC, 0);
     if (portfd < 0) {
         sprintf(tmp, "can not open UNIX %s", port);
-        logger("ERR", tmp);
+        logger(L_ERR, tmp);
         printf("ERROR: can not open UNIX %s\n", port);
-        portfd = 0;
+        portfd = -1;
         return -1;
     }
     memset(&serveraddr, 0, sizeof(serveraddr));
@@ -484,9 +489,9 @@ int unix_open_port(char* port)
     int ret = connect(portfd, (struct sockaddr *)&serveraddr, SUN_LEN(&serveraddr));
     if (ret < 0) {
         sprintf(tmp, "can not open UNIX socket %s", port);
-        logger("ERR", tmp);
+        logger(L_ERR, tmp);
         printf("ERROR: can not open UNIX socket %s\n", port);
-        portfd = 0;
+        portfd = -1;
         return -1;
     }
 
@@ -498,13 +503,13 @@ int unix_close_port()
     int retval = 0;
     //printf("INFO: Close port\n");
 
-    if (!portfd) { /* already closed */
+    if (portfd < 0) { /* already closed */
         //printf("INFO: Already closed ?\n");
         return -1;
     }
 
     retval = close(portfd);
-    portfd = 0;
+    portfd = -1;
 
     return retval;
 }
@@ -520,11 +525,11 @@ int unix_read_port(char* buf, int l)
 		int rc = recv(portfd, & buf[bytesReceived], l - bytesReceived, 0);
 		printf("unix_read_port %d\n",rc);
 		if (rc < 0) {
-	   		//logger("ERR","recv() failed");
+	   		//logger(L_ERR,"recv() failed");
 			ret = EOF-1;
 	   		break;
 		} else if (rc == 0) {
-	   		//logger("INF","Read 0 bytes");
+	   		//logger(L_INF,"Read 0 bytes");
 			ret = EOF;
 	   		break;
 		}
@@ -615,7 +620,7 @@ void sdpRegister(int port)
     // and disconnect
     session = sdp_connect(BDADDR_ANY, BDADDR_LOCAL, SDP_RETRY_IF_BUSY);
     if ( (!(session && record)) || sdp_record_register(session, record, 0) == -1) {
-        logger("ERR", "can not register SDP service");
+        logger(L_ERR, "can not register SDP service");
     }
 
     // cleanup
@@ -666,7 +671,7 @@ void sdpRegister(int port)
 
 static void sdpDeregister()
 {
-    logger("DBG", "Deregister SDP service");
+    logger(L_DBG, "Deregister SDP service");
 #ifdef USE_BLUEZ
     if (session != NULL) {
         sdp_record_unregister(session, record);
@@ -706,8 +711,8 @@ int openSocketPort(int type, int port, char *path)
     int proto     = 0;
     int sz;
 
-    if (sportfd) {
-        logger("ERR", "socket was already opened");
+    if (sportfd >= 0) {
+        logger(L_ERR, "socket was already opened");
         //close(sportfd);
         //sportfd = 0;
         return 1;
@@ -729,14 +734,14 @@ int openSocketPort(int type, int port, char *path)
         addFamily = AF_UNIX;
         proto	  = 0;
     } else {
-        logger("ERR", "incorrect input");
+        logger(L_ERR, "incorrect input");
         return -1;
     }
 
     if ((sportfd = socket(addFamily, SOCK_STREAM|SOCK_CLOEXEC, proto)) < 0) {
-        logger("ERR", "opening socket");
+        logger(L_ERR, "opening socket");
         printf("ERROR: opening socket\n");
-
+        sportfd = -1;
         return -1;
     }
 
@@ -780,7 +785,7 @@ int openSocketPort(int type, int port, char *path)
 
         sdpRegister(port);
         sprintf(tmp, "registered SP for channel %i", port);
-        logger("INF", tmp);
+        logger(L_INF, tmp);
         socketaddr=(struct sockaddr *)&bt_addr;
 #endif
 
@@ -792,7 +797,7 @@ int openSocketPort(int type, int port, char *path)
         bt_addr.rfcomm_channel =  (uint8_t) port;;
         sdpRegister(port);
         sprintf(tmp, "registered SP for channel %i", port);
-        logger("INF", tmp);
+        logger(L_INF, tmp);
 
         socketaddr=(struct sockaddr *)&bt_addr;
         sz = sizeof(bt_addr);
@@ -807,12 +812,12 @@ int openSocketPort(int type, int port, char *path)
         sz = sizeof(un_addr);
 
     } else {
-        logger("ERR", "incorrect input 2");
+        logger(L_ERR, "incorrect input 2");
         return -1;
     }
 
     if (bind(sportfd, (struct sockaddr *) socketaddr, sz) < 0) {
-        logger("ERR", "on binding");
+        logger(L_ERR, "on binding");
         printf("ERROR: on binding %d->%s\n", errno, strerror(errno));
         return -1;
     }
@@ -825,15 +830,17 @@ int openSocketPort(int type, int port, char *path)
 
 int closeSocketPort(int type, int final)
 {
-    /*if (final)*/ logger("INF", "closeSocketPort");
+    logger(L_INF, "closeSocketPort");
 
-    if (portfd) {
+    if (portfd >= 0) {
+        logger(L_INF, "closeSocketPort close socket");
         close(portfd);
-        portfd = 0;
+        portfd = -1;
     }
-    if (sportfd) {
+    if (sportfd >= 0) {
+        logger(L_INF, "closeSocketPort close server socket");
         close(sportfd);
-        sportfd = 0;
+        sportfd = -1;
     }
     if (type == SERVER_BT && final) {
         sdpDeregister();
@@ -862,7 +869,7 @@ int listenAndAcceptSocketConn(int type)
     struct sockaddr_rfcomm bt_addr;
 #endif
 
-    logger("INF", "listenAndAcceptSocketConn");
+    logger(L_INF, "listenAndAcceptSocketConn");
     cnt = 0;
 
     if (type == SERVER_BT) {
@@ -877,16 +884,16 @@ int listenAndAcceptSocketConn(int type)
 
     while (stillRun) {
 
-        logger("INF", "listenAndAcceptSocketConn: accept");
+        logger(L_INF, "listenAndAcceptSocketConn: accept");
 
         listen(sportfd,5);
 
         portfd = accept(sportfd, (struct sockaddr *) socketaddr, (socklen_t *)&sz);
 
-        if (portfd == -1 && errno == EAGAIN) {
+        if (portfd < 0 && errno == EAGAIN) {
 
             if (cnt >= 60) {    // Print to log every minute
-                logger("INF", "listenAndAcceptSocketConn: waiting for connection");
+                logger(L_INF, "listenAndAcceptSocketConn: waiting for connection");
                 //printf(".");
                 cnt = 0;
             }
@@ -899,7 +906,7 @@ int listenAndAcceptSocketConn(int type)
         }
 
         if (portfd < 0) {
-            logger("ERR", "on accept");
+            logger(L_ERR, "on accept");
             printf("ERROR: on accept %d\n", errno);
             return -1;
             /*} else {
@@ -910,7 +917,7 @@ int listenAndAcceptSocketConn(int type)
             	fcntl(portfd, F_SETFL, flags | O_NONBLOCK);
             */
         }
-        logger("INF", "listenAndAcceptSocketConn: accepted");
+        logger(L_INF, "listenAndAcceptSocketConn: accepted");
 
 #ifdef USE_BLUEZ
         if (type == SERVER_BT) {
@@ -921,7 +928,7 @@ int listenAndAcceptSocketConn(int type)
             btAddress = batostr(&ba);
 
             sprintf(tmp, "listenAndAcceptSocketConn: remote BT address is %s", btAddress);
-            logger("INF", tmp);
+            logger(L_INF, tmp);
         }
 #endif
 #ifdef USE_BT_FBSD
@@ -932,7 +939,7 @@ int listenAndAcceptSocketConn(int type)
             btAddress = strdup(bt_ntoa(&bt_addr.rfcomm_bdaddr, NULL));
 
             sprintf(tmp, "listenAndAcceptSocketConn: remote BT address is %s", btAddress);
-            logger("INF", tmp);
+            logger(L_INF, tmp);
         }
 #endif
 
@@ -941,15 +948,15 @@ int listenAndAcceptSocketConn(int type)
     return 1;
 }
 
-int writeSocketConn(char* command, int count)
+int writeSocketConn(const char* command, int count)
 {
-    //logger("DBG", "writeSocketConn");
+    //logger(L_DBG, "writeSocketConn");
     if (!command) {
         return EXIT_OK;
     }
 
     // send command
-    if (portfd > 0 && count > 0) {
+    if (portfd >= 0 && count > 0) {
 
         memset(tmp, 0, MAXMAXLEN);
         strcat(tmp, "writeSocketConn ");
@@ -960,20 +967,20 @@ int writeSocketConn(char* command, int count)
         // it is possible to get binary data here
         memcpy(tmp, command, logSz); // Do not dump long commands
         tmp[logSz] = '\0';
-        logger("DBG", tmp);
+        logger(L_DBG, tmp);
 
         sprintf(tmp, "writeSocketConn %d bytes", count);
-        logger("INF", tmp);
+        logger(L_INF, tmp);
 
         int n = write(portfd,command,count);
         if (n < 0) {
-            logger("ERR", "error writing to socket");
+            logger(L_ERR, "error writing to socket");
             return EXIT_NOK;
         }
         //tcdrain(portfd);
         return EXIT_OK;
     } else {
-        logger("ERR", "error writing to socket: already closed");
+        logger(L_ERR, "error writing to socket: already closed");
     }
     return EXIT_NOK;
 }
@@ -985,7 +992,7 @@ static int writeByteSocketConn(int byte)
     byte2write[1] = '\0';
 
     if (write(portfd, byte2write, 1) < 0) {
-        logger("ERR", "error writing byte to socket");
+        logger(L_ERR, "error writing byte to socket");
         return EXIT_NOK;
     }
     return EXIT_OK;
@@ -1002,10 +1009,10 @@ static void writeIViewerHeartbeat()
 
 int writeBytesSocketConn(char* command)
 {
-    //logger("DBG", "writeBytesSocketConn");
+    //logger(L_DBG, "writeBytesSocketConn");
 
     // send command
-    if (portfd > 0 && command && command[0]) {
+    if (portfd >= 0 && command && command[0]) {
 
         char byteStr[MAXCKPDLEN];
         memset(byteStr,0,MAXCKPDLEN);
@@ -1013,13 +1020,13 @@ int writeBytesSocketConn(char* command)
         strncpy(byteStr,command,MAXCKPDLEN-1);
 
         sprintf(tmp, "writeBytesSocketConn >%s<", byteStr);
-        logger("DBG", tmp);
+        logger(L_DBG, tmp);
 
         char* bStr = strtok(byteStr,",");
         while (bStr != NULL) {
 
             //sprintf(tmp, "Next byte is >%s<", bStr);
-            //logger("DBG", tmp);
+            //logger(L_DBG, tmp);
 
             char bStripped[4];
 
@@ -1035,7 +1042,7 @@ int writeBytesSocketConn(char* command)
             bStripped[i] = '\0';
 
             sprintf(tmp, "Next byte is >%s<", bStripped);
-            logger("DBG", tmp);
+            logger(L_DBG, tmp);
 
             if (writeByteSocketConn(atoi(bStripped)) != EXIT_OK) {
                 return EXIT_NOK;
@@ -1046,7 +1053,7 @@ int writeBytesSocketConn(char* command)
                 ivInCommand = 0;
 
                 if (ivHeartbeat) {
-                    logger("DBG", "Send buffered heartbeat message");
+                    logger(L_DBG, "Send buffered heartbeat message");
                     ivHeartbeat = 0;
                     writeIViewerHeartbeat();
                 }
@@ -1057,7 +1064,7 @@ int writeBytesSocketConn(char* command)
             bStr = strtok(NULL,",");
         }
     }
-    //logger("DBG", "writeBytesSocketConn EXIT");
+    //logger(L_DBG, "writeBytesSocketConn EXIT");
     return EXIT_OK;
 }
 
