@@ -32,7 +32,7 @@ int  closeSerialPort(int final);
 int  bt_read(char* buf, int len);
 int  bt_readchar(char* c, int timeout);
 int  bt_write(char* buf, int len);
-int  bt_put_command(char* command,
+int  bt_put_command(const char* command,
                     char* answer,
                     int   max,
                     int   timeout,
@@ -54,8 +54,8 @@ int unix_open_port (char* port);
 int unix_close_port();
 //int unix_read_port(char* buf, int l);
 
-int listenAndAcceptSocketConn();
-int writeSocketConn(char* command, int count);
+int listenAndAcceptSocketConn(int type);
+int writeSocketConn(const char* command, int count);
 int writeBytesSocketConn(char* command);
 int readSocketConn(char* buffer, int len);
 int sendKeepAlive(void);
