@@ -37,6 +37,9 @@
 
 #define IS_OK(answer) (strstr(answer, "OK") != NULL)
 
+//#define DEFAULT_DEVICE  "/dev/rfcomm0"	seems JSR-82 phones is more usable now
+#define DEFAULT_DEVICE  "bluetooth:19"
+
 #define AT_DEVICE   	"rfcomm"
 #define INET_SOCKET   	"socket:"
 #define BT_SOCKET   	"bluetooth"
@@ -45,19 +48,27 @@
 #define UNIX_SOCKET   	"local:"
 #define ILIRC_SOCKET   	"ilirc:"
 #define STDIN_STREAM   	"stdin"
+#define WEB_SOCKET   	"web:"
 
 #define TOFILE   	"/anyremote.result"
 #define CMDFILE   	"/anyremote.command"
 
-#define CLIENT_RFCOMM   0	// AT protocol over bluetooth
-#define CLIENT_AT       1	// AT protocol over IR or cable
-#define SERVER_TCP      2	// anyRemote protocol over TCP/IP
-#define SERVER_BT       3	// anyRemote protocol over btspp
-#define CLIENT_ILIRC    4	// inputLirc protocol
-#define SERVER_UX       5       // NOT USED: anyRemote protocol over IR (or any AF_UNIX socket) - as server
+#define PROTO_AT        1
+#define PROTO_ANYREMOTE 2
+#define PROTO_BEMUSED   3
+#define PROTO_IVIEWER   4
+
+#define CLIENT_RFCOMM   1	// AT protocol over bluetooth
+#define CLIENT_AT       2	// AT protocol over IR or cable
+#define SERVER_TCP      3	// anyRemote protocol over TCP/IP
+#define SERVER_BT       4	// anyRemote protocol over btspp
+#define CLIENT_ILIRC    5	// inputLirc protocol
 #define CLIENT_NOAT     6	// anyRemote protocol over IR (or any AF_UNIX socket) - as client
 #define SERVER_STDIN    7	// anyRemote protocol, read command from stdin
-#define SERVER_L2CAP    8	// TODO: anyRemote protocol over l2cap
+#define SERVER_WEB      8	// anyRemote protocol, built-in web server
+
+#define SERVER_L2CAP    101	// TODO: anyRemote protocol over l2cap
+#define SERVER_UX       102     // NOT USED: anyRemote protocol over IR (or any AF_UNIX socket) - as server
 
 #define DEFAULT_BT_CHANNEL 19
 #define BT_ADDR_LEN        17   // 00:12:EF:32:21:1A
