@@ -32,7 +32,7 @@
 
 extern char tmp[MAXMAXLEN];
 
-extern type_key* findExact(mode *mode, char *key);
+extern type_key* findExact(mode *mode, const char *key);
 
 extern mode       *modes;
 extern mode       *currentMode;
@@ -46,11 +46,11 @@ int initDone = 0;
 /* ----------------- Interface functions ------------------------- */
 
 // caller function must free data
-static char* dupVarValue(char *name, int size)
+static char* dupVarValue(const char *name, int size)
 {
     varData* v = searchVar(name, size);
     if (v != NULL && v->value != NULL && v->value[0] != '\0') {
-        char *d = calloc(1,v->size+1);
+        char *d = (char*) calloc(1,v->size+1);
         strncpy(d,v->value,v->size);
         d[v->size] = '\0';
         return d;
@@ -60,8 +60,8 @@ static char* dupVarValue(char *name, int size)
 
 int getLog()
 {
-    varData* v = searchVar("Logging", 7);
-    if (v != NULL && strncmp(v->value,"false",5) != 0) {
+    const char* v = getVarValue("Logging");
+    if (v != NULL && strncmp(v,"false",5) != 0) {
         return 1;
     }
     return 0;
@@ -69,8 +69,8 @@ int getLog()
 
 int getDebug()
 {
-    varData* v = searchVar("Logging", 7);
-    if (v != NULL && strncmp(v->value,"debug",5) == 0) {
+    const char* v = getVarValue("Logging");
+    if (v != NULL && strncmp(v,"debug",5) == 0) {
         return 1;
     }
     return 0;
@@ -83,14 +83,10 @@ char* getDevice()
 
 int getBaudrate()
 {
-    char br[16];	// enough for 234000
-    memset(br,0,16);
+    const char* value = getVarValue("Baudrate");
+    if (value != NULL) {
 
-    varData* v = searchVar("Baudrate", 12);
-    if (v != NULL) {
-        strncpy(br,v->value,v->size);
-
-        int rate = atoi(br);
+        int rate = atoi(value);
 
         switch (rate) {
         case 300:
@@ -127,20 +123,17 @@ int getBaudrate()
 
 int getRetrySecs()
 {
-    char rs[16];	// should be enough
-    memset(rs,0,16);
-    varData* v = searchVar("RetrySeconds", 12);
-    if (v != NULL) {
-        strncpy(rs,v->value,v->size);
-        return atoi(rs);
+    const char* value = getVarValue("RetrySeconds");
+    if (value != NULL) {
+        return atoi(value);
     }
     return 10;
 }
 
 int autoConnect()
 {
-    varData* v = searchVar(AUTOCONN_STR, 11);
-    if (v != NULL && strncmp(v->value,"true",4) == 0) {
+    const char* v = getVarValue(AUTOCONN_STR);
+    if (v != NULL && strncmp(v,"true",4) == 0) {
         return 1;
     }
     return 0;
@@ -148,8 +141,8 @@ int autoConnect()
 
 int getIViewer()
 {
-    varData* v = searchVar("IViewer", 7);
-    if (v != NULL && strncmp(v->value,"true",4) == 0) {
+    const char* v = getVarValue("IViewer");
+    if (v != NULL && strncmp(v,"true",4) == 0) {
         return 1;
     }
     return 0;
@@ -158,8 +151,8 @@ int getIViewer()
 
 int getAutoRepeat()
 {
-    varData* v = searchVar(AUTOREPEAT_STR, 10);
-    if (v != NULL && strncmp(v->value,"true",4) == 0) {
+    const char* v = getVarValue(AUTOREPEAT_STR);
+    if (v != NULL && strncmp(v,"true",4) == 0) {
         return 1;
     }
     return 0;
@@ -179,8 +172,8 @@ type_key* repeatNow()
 
 int getUseScreen()
 {
-    varData* v = searchVar("TwoWayComm", 10);
-    if (v != NULL && strncmp(v->value,"true",4) == 0) {
+    const char* v = getVarValue("TwoWayComm");
+    if (v != NULL && strncmp(v,"true",4) == 0) {
         return 1;
     }
     return 0;
@@ -262,6 +255,11 @@ int usePassword()
 
 
 char* getCfgDir(void)
+{
+    return dupVarValue("CfgDir", 6);
+}
+
+char* getConfigDir(void)
 {
     return conf.cfgDir;
 }
@@ -298,7 +296,7 @@ int getModel (void)
 void addAlarm(char *file, char *macro)
 {
     sprintf(tmp,"addAlarm() >%s< >%s<\n", file,macro);
-    logger("DBG",tmp);
+    logger(L_DBG,tmp);
 
     type_alarm * v = (type_alarm *) calloc(sizeof(type_alarm),1);
     v->file  = strdup(file);
@@ -318,7 +316,7 @@ static type_alarm *tk = NULL;
 char* getFirstAlarm(char** macro)
 {
     if (alarms == NULL) {
-        //logger("DBG","no any alarm found");
+        //logger(L_DBG,"no any alarm found");
         return NULL;
     }
     tk = alarms;
@@ -343,7 +341,7 @@ char* getNextAlarm(char** macro)
 
 /////////////////////////////////////////////////////////////////////////////////////////////////
 
-static type_key* findStartingWith(mode *mode, char *key)
+static type_key* findStartingWith(mode *mode, const char *key)
 {
     if (mode == NULL) {
         return NULL;
@@ -355,8 +353,23 @@ static type_key* findStartingWith(mode *mode, char *key)
 
         if (start && start == It->key) {    // We got a part of multi-key or parametrized command
 
-            logger("DBG","Found part of multi-key or parametrized command");
-            return It;
+            int lk = strlen(key);
+            int l2 = strlen(It->key);
+	    int ok = 1;
+	    
+            if (*(key+lk-1) != '$' &&   // not parametrized
+	       l2 > lk) {            // part of multi-key should be followed by space
+	    
+	        char next = *(It->key+lk);
+		if (next != ' ') {
+		    ok = 0;
+		}
+	    }
+	    
+	    if (ok == 1)  {
+        	logger(L_DBG,"Found part of multi-key or parametrized command");
+        	return It;
+	    }
         }
         It = (type_key*) It->next;
     }
@@ -364,27 +377,27 @@ static type_key* findStartingWith(mode *mode, char *key)
     return It;
 }
 
-static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *params)
+static type_key* findItemInMode(mode *mode, const char *key, int *flag, cmdParams *params)
 {
     if (mode == NULL) {
-        logger("DBG","findItemInMode: mode is null");
+        logger(L_DBG,"findItemInMode: mode is null");
         return NULL;
     }
     int canLog = (strcmp(mode->name,"_INTERNAL_") != 0);
 
     if(canLog) {
         sprintf(tmp,"findItemInMode >%s,%s<", mode->name, key);
-        logger("DBG",tmp);
+        logger(L_DBG,tmp);
     }
 
     // Prepare to search as parametrized command, control presence of both ( and )
-    char *start  = index(key,'(');
-    char *finish = rindex(key,')');
+    const char *start  = index(key,'(');
+    const char *finish = rindex(key,')');
 
     if ((start != NULL && finish == NULL) ||  // Command was read partially?
             (start == NULL && finish != NULL)) {  // Command was incorectrly formed ?
         if(canLog) {
-            logger("DBG","findItemInMode: Incorrectly formed parametrized command. One brace is absent");
+            logger(L_DBG,"findItemInMode: Incorrectly formed parametrized command. One brace is absent");
         }
         return NULL;
     }
@@ -397,21 +410,21 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 
     type_key* It = findExact(mode,key);	// Search exact command
     if (It) {
-        //logger("DBG","Found exact command");
+        //logger(L_DBG,"Found exact command");
         *flag = FLAG_EXACT;
         return It;
     }
 
     It = findStartingWith(mode,key);	// Search as part of multikey sequence
     if (It) {
-        //logger("DBG","Found part of multi-key command");
+        //logger(L_DBG,"Found part of multi-key command");
         *flag = FLAG_MULTIKEY;
         return It;
     }
 
     if (params == NULL) {
         if(canLog) {
-            logger("DBG","findItemInMode: No parameters suspected. Item does not found.");
+            logger(L_DBG,"findItemInMode: No parameters suspected. Item does not found.");
         }
         return NULL;
     }
@@ -431,17 +444,17 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
         strncpy(tag, key, start-key);
         *(tag+(start-key)) = '\0';
 
-        char *comma = strstr(start+1,",");
+        const char *comma = strstr(start+1,",");
         if (comma == NULL || comma > finish) { // Parametrized command from Java Client should be in a form like List(1,String1)
             if(canLog) {
-                logger("DBG","findItemInMode: Incorrectly formed parametrized command");
+                logger(L_DBG,"findItemInMode: Incorrectly formed parametrized command");
             }
             return NULL;
         }
 
         if (comma-start > 6) { // 65535 = max value in Comman Fusion iViewer
             if(canLog) {
-                logger("ERR","findItemInMode: Received incorrect index!");
+                logger(L_ERR,"findItemInMode: Received incorrect index!");
             }
             return NULL;
         }
@@ -453,7 +466,7 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 
         if(canLog) {
             sprintf(tmp,"Parametrized command parsed as >%s< >%s< >%s< ", tag,index,value);
-            logger("DBG",tmp);
+            logger(L_DBG,tmp);
         }
 
         // Try to search explicitly specified parametrized command (for ex List(1) or List(commandX))
@@ -465,7 +478,7 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 
         if (It) {
             if(canLog) {
-                logger("DBG","Found exact (explicitly specified by index) parametrized command");
+                logger(L_DBG,"Found exact (explicitly specified by index) parametrized command");
             }
             *flag = FLAG_EXACT;
             return It;
@@ -479,7 +492,7 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
 
         if (It) {
             if(canLog) {
-                logger("DBG","Found exact (explicitly specified by value) parametrized command");
+                logger(L_DBG,"Found exact (explicitly specified by value) parametrized command");
             }
             *flag = FLAG_EXACT;
             return It;
@@ -488,7 +501,7 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
         // Finally... Search command like ListItem($$)
         *(tag+(start-key)) = '\0';
 
-        char* keyAndBrace = calloc(1,strlen(tag)+3);
+        char* keyAndBrace = (char*) calloc(1,strlen(tag)+3);
         strcpy(keyAndBrace,tag);
         strcat(keyAndBrace,"($");
 
@@ -509,14 +522,14 @@ static type_key* findItemInMode(mode *mode, char *key, int *flag, cmdParams *par
         }
     }
     if(canLog) {
-        logger("DBG","findItemInMode: Item does not found");
+        logger(L_DBG,"findItemInMode: Item does not found");
     }
     return NULL;
 }
 
-type_key* findItem(char *keyIn, int *flag, cmdParams *params)
+type_key* findItem(const char *keyIn, int *flag, cmdParams *params)
 {
-    //logger("DBG","findItem()");
+    //logger(L_DBG,"findItem()");
     type_key *tk = NULL;
 
     if (keyIn == NULL) {
@@ -527,7 +540,7 @@ type_key* findItem(char *keyIn, int *flag, cmdParams *params)
     memset(key,0,MAXARGLEN);
 
     if (*keyIn == '\0') {
-        logger("INF","Got empty key");
+        logger(L_INF,"Got empty key");
         strcpy(key, EMPTY_STR);
     } else {
         strncpy(key, keyIn, MAXARGLEN - 1);
@@ -552,17 +565,17 @@ type_key* findItem(char *keyIn, int *flag, cmdParams *params)
         }
 
         if (tk == NULL && currentMode != defMode) {
-            logger("DBG","findItem() search in default");
+            logger(L_DBG,"findItem() search in default");
             tk = findItemInMode(defMode, key, flag, params);
         }
     }
 
     //  Search in "internal" commands
     if (tk == NULL) {
-        logger("DBG","findItem() internal mode");
+        logger(L_DBG,"findItem() internal mode");
         tk = findItemInMode(internalMode, key, flag, params);
         if (tk != NULL && *flag == FLAG_MULTIKEY) {
-            logger("DBG","findItem() multikey in internal command ?");
+            logger(L_DBG,"findItem() multikey in internal command ?");
         }
     }
 
@@ -577,16 +590,16 @@ type_key* findItem(char *keyIn, int *flag, cmdParams *params)
 cmdItem *getCommand(type_key* item)
 {
     if (!item) {
-        logger("DBG","getCommand(): Empty type_key was got");
+        logger(L_DBG,"getCommand(): Empty type_key was got");
         return NULL;
     }
     if (item->key == NULL) {
-        logger("DBG","Empty key was got");
+        logger(L_DBG,"Empty key was got");
         return NULL;
     }
 
     sprintf(tmp,"getCommand for >%s<", item->key);
-    logger("DBG",tmp);
+    logger(L_DBG,tmp);
 
     return item->cmd;
 }
@@ -641,13 +654,13 @@ void printKeysInMode(type_key* It)
                 if (item) {
                     strcat(tmp, "\\");
                 }
-                logger("CFG", tmp);
+                logger(L_CFG, tmp);
                 sprintf(tmp, "\t\t");
 
             }
         } else {
             sprintf(tmp, "\t%s = no command", It->key);
-            logger("CFG", tmp);
+            logger(L_CFG, tmp);
         }
 
         It = (type_key*)It->next;
@@ -665,14 +678,14 @@ void printKeys()
         } else {
             sprintf(tmp, "%s %s : %s", MODE_STR, mp->name, mp->parent);
         }
-        logger("CFG", tmp);
+        logger(L_CFG, tmp);
 
         type_key* It = mp->keys;
 
         printKeysInMode(It);
 
         sprintf(tmp, "%s %s", MODE_END_STR, mp->name);
-        logger("CFG", tmp);
+        logger(L_CFG, tmp);
 
         mp = (mode*)mp->next;
     }
@@ -725,7 +738,7 @@ void freeCmds(cmdItem* item)
 
 void freeCfgEx(mode* pmodes, type_alarm* palarms)
 {
-    //logger("DBG", "freeCfgEx()");
+    //logger(L_DBG, "freeCfgEx()");
 
     // Keys
     while(pmodes) {
