@@ -28,6 +28,7 @@ char* getFirstAlarm     (char **cmds);
 char* getNextAlarm      (char **cmds);
 char* getAT_CMER     	(int what);
 char* getCfgDir         (void);
+char* getConfigDir      (void);
 char* getCharset        (void);
 char* getDevice         (void);
 char* getMode           (void);
@@ -57,7 +58,7 @@ void  setInitDone       (void);
 void setRepeatNow       (type_key *k);
 type_key* repeatNow     ();
 
-type_key* findItem	(char *key, int *flag, cmdParams *param);
+type_key* findItem	(const char *key, int *flag, cmdParams *param);
 cmdItem* getCommand	(type_key* item);
 
 #endif
