@@ -25,27 +25,34 @@
 #include <glib.h>
 
 #define DM_SET		1
-#define DM_SENDB	2
-#define DM_SENDS	3
-#define DM_CKPD 	4
-#define DM_CMER 	5
-#define DM_SETL2 	6
-#define DM_SENDBL2 	7
-#define DM_SENDBL2 	7
+#define DM_SETFILE	2
+#define DM_SENDB	3
+#define DM_SENDS	4
+#define DM_CKPD 	5
+#define DM_CMER 	6
 
 #define DM_EVENT_INIT       98
 #define DM_EVENT_DISCONNECT 99
 #define DM_EVENT_EXIT	    100
 
-typedef struct ed {
+typedef struct {
     int        type;
     int        size;
     void*      value;
+    char*      file;
 } dMessage;
 
-void  	 createDataDir		(void);
+typedef struct {
+    //int      proto;
+    int      mode;
+    int      port; 
+    GString  *portStr;
+    gboolean connected;  
+} ConnectInfo;
+
 gpointer dispatcherRoutine	(gpointer thread);
 void  	 sendToDispatcher  	(dMessage *buf);
 void     parseCommand           (char* cmd);
+void     closePort              (int final);
 
 #endif
