@@ -44,13 +44,11 @@ extern GAsyncQueue *q2main;
 extern int  gotSignal;
 extern gboolean stillRun;
 
-extern int  serverMode;
-
 extern int  useCallId;
 extern int  callOn;
 extern int  callTimer;
 extern char callerId[MAXLEN];
-
+extern ConnectInfo connectInfo;
 
 static int  handle_command(char* cmd);
 static int  handle_alarm  (char* cmd) ;
@@ -88,56 +86,64 @@ void sendToExecutor(eMessage *buf)
 
 void sendEventToExecutor(int event)
 {
-    eMessage* em = malloc(sizeof(eMessage));
+    eMessage* em = (eMessage*) malloc(sizeof(eMessage));
     em->type  = EM_EVENT;
     em->value = malloc(sizeof(int));
     *((int *)em->value) = event;
 
     sendToExecutor(em);
+    
+    if (getHttp() || connectInfo.mode == SERVER_WEB) {
 
-    //free(em);
+        eMessage* em = (eMessage*) malloc(sizeof(eMessage));
+        em->type  = EM_AS_IS;
+        em->value = strdup("End();");
+        sendToExecutor(em);
+    }
 }
 
 gpointer executorRoutine(gpointer thread)
 {
     if (q2exec == NULL) {
-        logger("INF","[EX]: Do not start executor thread");
+        logger(L_INF,"[EX]: Do not start executor thread");
         return NULL;
     }
 
-    logger("INF","[EX]: Start executor thread");
+    logger(L_INF,"[EX]: Start executor thread");
     int exitFlag = 0;
 
     dbusInit();
-    //logger("INF","[EX]: DBUS initialized");
+    //logger(L_INF,"[EX]: DBUS initialized");
     handleInit();
-    //logger("INF","[EX]: init hooks done");
+    //logger(L_INF,"[EX]: init hooks done");
 	   
     setInitDone();
     printConf();
 
-    dMessage* dm = malloc(sizeof(dMessage));
+    dMessage* dm = (dMessage*) malloc(sizeof(dMessage));
     dm->size  = 0;
     dm->value = (void*) NULL;
     dm->type  = DM_EVENT_INIT;
+    dm->file  = NULL;
+    
     sendToDispatcher(dm);
 
     while (stillRun) {
 
-        //logger("DBG", "[EX]: LOOP");
+        //logger(L_DBG, "[EX]: LOOP");
 
         eMessage *em = (eMessage *) g_async_queue_try_pop(q2exec);
 
         if (em != NULL) {
 
-            //logger("DBG", "[EX]: got event");
+            //logger(L_DBG, "[EX]: got event");
 
             if (em->type == EM_KEY) {
 
                 char * cmd = (char *) em->value;
 
                 sprintf(tmp, "[EX]: got key >%s<", (cmd ? cmd : "NULL"));
-                logger("DBG", tmp);
+                logger(L_DBG, tmp);
 
                 handle_command(cmd);
                 free(em->value);
@@ -146,7 +152,7 @@ gpointer executorRoutine(gpointer thread)
 
                 cmdItem *pg = (cmdItem*) em->value;
 
-                logger("DBG", "[EX]: got cmdItem");
+                logger(L_DBG, "[EX]: got cmdItem");
 
                 processCommands(pg, NULL);
 
@@ -155,7 +161,7 @@ gpointer executorRoutine(gpointer thread)
                 char * msgIn = (char*) em->value;
 
                 sprintf(tmp, "[EX]: got string >%s<", msgIn);
-                logger("DBG", tmp);
+                logger(L_DBG, tmp);
 
                 execDynamically(msgIn);
                 free(em->value);
@@ -165,7 +171,7 @@ gpointer executorRoutine(gpointer thread)
                 int* evt = (int*) em->value;
 
                 sprintf(tmp, "[EX]: got event >%d<", *evt);
-                logger("DBG", tmp);
+                logger(L_DBG, tmp);
 
                 if (*evt == ID_EVT_CONNECT) {
                     handleConnect();
@@ -186,7 +192,7 @@ gpointer executorRoutine(gpointer thread)
                 char * cmd = (char *) em->value;
 
                 sprintf(tmp, "[EX]: got alarm >%s<", cmd);
-                logger("DBG", tmp);
+                logger(L_DBG, tmp);
 
                 handle_alarm(cmd);
 
@@ -194,12 +200,14 @@ gpointer executorRoutine(gpointer thread)
 
             } else if (em->type == EM_AS_IS) {
 
-                logger("DBG", "[EX]: got as is");
+                logger(L_DBG, "[EX]: got as is");
 
-                dMessage* dm = malloc(sizeof(dMessage));
+                dMessage* dm = (dMessage*) malloc(sizeof(dMessage));
                 dm->type  = DM_SET;
-                dm->size  = strlen(em->value);
-                dm->value = (void*) strdup(em->value);
+                dm->size  = strlen((char*)em->value);
+                dm->value = (void*) strdup((char*)em->value);
+		dm->file  = NULL;
+		
                 sendToDispatcher(dm);
 
                 free(em->value);
@@ -211,7 +219,7 @@ gpointer executorRoutine(gpointer thread)
                 return NULL;
             }
         }
-        //logger("DBG", "[EX]: command processed of empty input");
+        //logger(L_DBG, "[EX]: command processed of empty input");
 
         // Should we auto-repeat command (timeout about 1/10 second) ?
         if (repeatNow() && getAutoRepeat()) {
@@ -226,7 +234,7 @@ gpointer executorRoutine(gpointer thread)
 
                 repeatTimer++;
             } else {
-                //logger("DBG","[EX]: Auto repeat command ...Skip");
+                //logger(L_DBG,"[EX]: Auto repeat command ...Skip");
                 repeatTimer++;
             }
         }
@@ -234,8 +242,8 @@ gpointer executorRoutine(gpointer thread)
         //DEBUG2("[EX]: check timers(%d)", commandTimer);
         // Verify commands executed by timer (timeout about 1 sec)
         if (commandTimer == 50) {
-            //logger("DBG","[EX]: Verify timer commands ...");
-            verifyTimers(1) ;
+            //logger(L_DBG,"[EX]: Verify timer commands ...");
+            verifyTimerCfg(1) ;
             commandTimer = 0;
 
         } else {
@@ -243,11 +251,11 @@ gpointer executorRoutine(gpointer thread)
         }
 
         if (!stillRun) {
-            logger("DBG","[EX]: Break from loop ...");
+            logger(L_DBG,"[EX]: Break from loop ...");
             break;
         }
 
-        //logger("DBG", "[EX]: wait a bit");
+        //logger(L_DBG, "[EX]: wait a bit");
         usleep(20000); // loop timer (1/50 of second)
     }
 
@@ -259,7 +267,7 @@ static void handleInit()
     int i = 0;
     type_key *k = findItem(EVT_INIT, &i, NULL);
     if (k && i == FLAG_EXACT) {
-        logger("INF", "[EX]: Exec cmd on init");
+        logger(L_INF, "[EX]: Exec cmd on init");
         handleCmdByKey(k,NULL);
     }
     handleHook(ID_EVT_INIT);
@@ -271,7 +279,7 @@ static void handleConnect()
     int ok1 = EXIT_NOK;
     type_key *k = findItem(EVT_CONNECT, &i, NULL);
     if (k && i == FLAG_EXACT) {
-        logger("INF", "[EX]: Exec cmd on connect");
+        logger(L_INF, "[EX]: Exec cmd on connect");
         ok1 = EXIT_OK;
 
         handleCmdByKey(k,NULL);
@@ -281,10 +289,12 @@ static void handleConnect()
     if (ok1 == EXIT_OK || ok2 == EXIT_OK) {
         if (getHttp()) {
 
-            dMessage* dm = malloc(sizeof(dMessage));
+            dMessage* dm = (dMessage*) malloc(sizeof(dMessage));
             dm->type  = DM_SET;
             dm->size  = 6;
             dm->value = (void*) strdup("End();");
+	    dm->file  = NULL;
+	    
             sendToDispatcher(dm);
         }
     }
@@ -298,7 +308,7 @@ static void handleDisconnect()
 
     type_key *k = findItem(EVT_DISCONNECT, &i, NULL);
     if (k && i == FLAG_EXACT) {
-        logger("INF", "[EX]: Exec cmd on disconnect");
+        logger(L_INF, "[EX]: Exec cmd on disconnect");
         handleCmdByKey(k,NULL);
     }
     handleHook(ID_EVT_DISCONNECT);
@@ -311,7 +321,7 @@ static void handleEndcall()
     int i = 0;
     type_key *k = findItem(EVT_ENDCALL, &i, NULL);
     if (k != NULL && i == FLAG_EXACT) {
-        logger("INF","[EX]: EVT_ENDCALL found");
+        logger(L_INF,"[EX]: EVT_ENDCALL found");
         handleCmdByKey(k,NULL);
     }
 }
@@ -322,7 +332,7 @@ static void handleExit()
     int i;
     type_key *k = findItem(EVT_EXIT, &i, NULL);
     if (k && i == FLAG_EXACT) {
-        logger("INF", "[EX]: Exec cmd on exit");
+        logger(L_INF, "[EX]: Exec cmd on exit");
         handleCmdByKey(k,NULL);   // Since we exiting now we did not interested in return code
     }
     printf("[EX]: handleExit handleHook\n");
@@ -340,7 +350,7 @@ static void handleExit()
 static void cleanAutoRepeatFlag()
 {
     // Clear auto repeat flag
-    logger("DBG","[EX]: Clean auto repeat flag");
+    logger(L_DBG,"[EX]: Clean auto repeat flag");
     setRepeatNow(NULL);
     repeatTimer  = 0;
 }
@@ -361,7 +371,7 @@ static int handle_alarm(char* key)
         handleCmdByKeyEx(k, NULL,0);
 
         if (flushConf == 1) {
-            logger("DBG", "Flush old configuration");
+            logger(L_DBG, "Flush old configuration");
             flushConf = 0;
 
             flushOldConf();
@@ -396,7 +406,7 @@ static int handle_key_press(char* key,int isRepeatable)
 
     if (k && i == FLAG_EXACT) {
         if (isRepeatable && (!repeatNow()) && getAutoRepeat()) {
-            logger("DBG", "Set auto repeat flag");
+            logger(L_DBG, "Set auto repeat flag");
             setRepeatNow(k);
         }
         handleCmdByKey(k, NULL);
@@ -405,24 +415,24 @@ static int handle_key_press(char* key,int isRepeatable)
         modifierString[0] = '\0';
 
         if (flushConf == 1) {
-            logger("DBG", "Flush old configuration");
+            logger(L_DBG, "Flush old configuration");
             flushConf = 0;
 
             flushOldConf();
         }
 
     } else if (k && i == FLAG_MULTIKEY) {
-        logger("DBG", "Got part of multi keys sequence. Nothing to do.");
+        logger(L_DBG, "Got part of multi keys sequence. Nothing to do.");
         if (modifierString[0] == '\0') {
-            logger("DBG", "Start of multi key sequence");
+            logger(L_DBG, "Start of multi key sequence");
             strcpy(modifierString, key);
         }
 
-        if(serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT) {
+        if(connectInfo.mode == CLIENT_RFCOMM || connectInfo.mode == CLIENT_AT) {
             sendToMainMenu();
         }
     } else if (k && i == FLAG_PARAMETR) {
-        logger("DBG", "Got parametrized command");
+        logger(L_DBG, "Got parametrized command");
 
         handleCmdByKey(k, &params);
 
@@ -432,15 +442,15 @@ static int handle_key_press(char* key,int isRepeatable)
     } else {
         // User had pressed some key ...
         // Send ToMainMenu sequence of CKPD's to show main menu again
-        if (serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT) {
+        if (connectInfo.mode == CLIENT_RFCOMM || connectInfo.mode == CLIENT_AT) {
             sendToMainMenu();
         }
 
-        logger("DBG", "No approprite key definition was found by findItem()");
+        logger(L_DBG, "No approprite key definition was found by findItem()");
         if (modifierString[0] != '\0') {
             // Clean modifier string
             modifierString[0] = '\0';
-            logger("DBG", "Clean modifier string");
+            logger(L_DBG, "Clean modifier string");
         }
     }
 
@@ -449,7 +459,7 @@ static int handle_key_press(char* key,int isRepeatable)
 
 static int handle_command(char* cmd)
 {
-    logger("DBG","[EX]: handle_command");
+    logger(L_DBG,"[EX]: handle_command");
 
     if (!cmd) {
         return EXIT_OK;
@@ -465,7 +475,7 @@ static int handle_command(char* cmd)
 
         key = cmd+4;
 
-        logger("DBG","[EX]: Got event from client");
+        logger(L_DBG,"[EX]: Got event from client");
         return handle_key_press(key,0);
 
     } else if (memcmp(cmd, DEF_CKEV, 6) == 0) {
@@ -484,12 +494,12 @@ static int handle_command(char* cmd)
 
         if (*key == '"') {	// Seems this is Motorola
             key++;
-            //logger("DBG","[EX]: +CKEV is in Motorola format");
+            //logger(L_DBG,"[EX]: +CKEV is in Motorola format");
             isSE = MODEL_MOTOROLA;
         }
 
         if (*key == ',') {	// Seems this is Sagem
-            logger("DBG","[EX]: +CKEV is in rare Sagem format (Empty code)");
+            logger(L_DBG,"[EX]: +CKEV is in rare Sagem format (Empty code)");
             isSE = MODEL_SAGEM;
         }
 
@@ -512,15 +522,15 @@ static int handle_command(char* cmd)
         } else if (isSE == MODEL_SAGEM) {	// rare Sagem case
             *key ='\0';
         } else {
-            logger("ERR","[EX]: Can't recognize +CKEV event !!!");
+            logger(L_ERR,"[EX]: Can't recognize +CKEV event !!!");
             return EXIT_NOK;
         }
 
         if (key[i] == '1') {
-            //logger("DBG","[EX]: Button down event");
+            //logger(L_DBG,"[EX]: Button down event");
             return handle_key_press(key,1);
         } else if (key[i] == '0') {
-            //logger("DBG","[EX]: Button up event");
+            //logger(L_DBG,"[EX]: Button up event");
             // In general we skip this
             cleanAutoRepeatFlag();
 
@@ -531,23 +541,23 @@ static int handle_command(char* cmd)
         }
     } else if (memcmp(cmd, DEF_CLCC,6) == 0) {
 
-        //logger("INF","[EX]: Caller ID received. Skip it.");
+        //logger(L_INF,"[EX]: Caller ID received. Skip it.");
         return EXIT_OK;
 
     } else if (strstr(cmd, DEF_RING) != NULL) {	// Incoming call
-        logger("INF","[EX]: Incoming call"); 	// This event sent periodically until used answered a call
+        logger(L_INF,"[EX]: Incoming call"); 	// This event sent periodically until used answered a call
 
         if (callOn == 0) {
             if (useCallId) {
-                //logger("DBG", "[EX]: Get CallerId on incoming call");
+                //logger(L_DBG, "[EX]: Get CallerId on incoming call");
                 int ret = getClip(callerId);
 
                 INFO2("[EX]: CallerId is %s",callerId);
 
                 if(ret == EXIT_EXACT) { // Active call exists
-                    //	logger("DBG","[EX]: Caller ID received");
+                    //	logger(L_DBG,"[EX]: Caller ID received");
                     //} else {
-                    logger("DBG","[EX]: Can't get Caller ID. Probably call was finished");
+                    logger(L_DBG,"[EX]: Can't get Caller ID. Probably call was finished");
                 }
             }
             //
@@ -558,7 +568,7 @@ static int handle_command(char* cmd)
             type_key* k = findItem(EVT_INCALL, &i, NULL);
 
             if (k && i == FLAG_EXACT) {
-                logger("DBG", "[EX]: Exec cmd on incoming call");
+                logger(L_DBG, "[EX]: Exec cmd on incoming call");
                 handleCmdByKey(k,NULL);
             }
 
@@ -566,14 +576,14 @@ static int handle_command(char* cmd)
             i = 0;
             k = findItem(EVT_ENDCALL, &i, NULL);
             if (k && i == FLAG_EXACT) {
-                logger("DBG", "[EX]: Set call timer");
+                logger(L_DBG, "[EX]: Set call timer");
                 callTimer = 0;
                 callOn    = 1;
             }
 
             return EXIT_OK;
         } else {
-            logger("DBG","[EX]: Skip it."); // This event sent periodically until used answered a call
+            logger(L_DBG,"[EX]: Skip it."); // This event sent periodically until used answered a call
         }
     } else if (isLircCommand(cmd)) {	    // LIRC tricks
         return EXIT_OK;
@@ -583,7 +593,7 @@ static int handle_command(char* cmd)
         return EXIT_OK;
     } else if (isIViewerCommand(cmd)) {	    // CommandFusion iViewer protocol support
         return EXIT_OK;
-    } else { /*if (serverMode == SERVER_STDIN)*/     // Just direct input, try it
+    } else { /*if (connectInfo.mode == SERVER_STDIN)*/     // Just direct input, try it
         //printf("DEBUG: Is it SERVER_STDIN ? %s\n", cmd);
 
         char *p = cmd;
@@ -607,14 +617,15 @@ static int handle_command(char* cmd)
 //
 void sendToMainMenu()
 {
-    logger("INF","[EX]: sendToMainMenu");
+    logger(L_INF,"[EX]: sendToMainMenu");
     char *tmm = NULL;
     if ((tmm = getToMainMenu()) != NULL) {
 
-        dMessage* dm = malloc(sizeof(dMessage));
+        dMessage* dm = (dMessage*) malloc(sizeof(dMessage));
         dm->type  = DM_CKPD;
         dm->value = (void*) tmm;
-        dm->size  = strlen(dm->value);
+        dm->size  = strlen((char*) dm->value);
+	dm->file  = NULL;
 
         sendToDispatcher(dm);
     }
@@ -627,7 +638,7 @@ void sendToMainMenu()
 
 static int isBemusedCommand(char *cmdIn)
 {
-    DEBUG2("isBemusedCommand: >%s<",cmdIn);
+    DEBUG2("[EX]: isBemusedCommand: >%s<",cmdIn);
 
     int isBemused = 0;
 
@@ -683,7 +694,7 @@ static int isBemusedCommand(char *cmdIn)
 
             // this must be handled in dispatcher thread
             if (strlen(cmd) == 4) {  	// read only VOLM without value to set
-                logger("ERR","got VOLM without value");
+                logger(L_ERR,"got VOLM without value");
                 return 1;		// do nothing, but treat it as Bemused command
             }
             bc = ((unsigned char) *(cmd + 4));
@@ -691,7 +702,7 @@ static int isBemusedCommand(char *cmdIn)
             // VOLM 0-255 -> 0%-100%
             sprintf(paramValue, "%d", ((int)bc * 100)/255);
 
-            DEBUG2("isBemusedCommand: VOLM parameter >%s<", paramValue);
+            DEBUG2("[EX]: isBemusedCommand: VOLM parameter >%s<", paramValue);
 
             handle = 1;
             shift  = 5;
@@ -704,7 +715,7 @@ static int isBemusedCommand(char *cmdIn)
             unsigned int ix = bc1*256+bc2;
             sprintf(paramValue, "%d",ix);
 
-            DEBUG2("isBemusedCommand: SLCT parameter >%s<", paramValue);
+            DEBUG2("[EX]: isBemusedCommand: SLCT parameter >%s<", paramValue);
 
             handle = 1;
             shift  = 6;
@@ -742,7 +753,7 @@ static int isBemusedCommand(char *cmdIn)
                 strcat(oneCmd,")");
             }
 
-            DEBUG2("isBemusedCommand: one commmand >%s<", oneCmd);
+            DEBUG2("[EX]: isBemusedCommand: one commmand >%s<", oneCmd);
 
             handle_key_press(oneCmd,1);
         } else {
@@ -762,7 +773,7 @@ static int isLircCommand(char *cmdIn)
 {
     //  should got replay in form "0000000000010184 00 TEXT linux-input-layer"
     //                            "0000000000010192 00 CHANNELUP linux-input-layer"
-    DEBUG2("isLircCommand: >%s<",cmdIn);
+    DEBUG2("[EX]: isLircCommand: >%s<",cmdIn);
 
     char *cmd = strdup(cmdIn);
     char *bufPtr = NULL;
@@ -802,11 +813,11 @@ static int isInpLircCommand(char *cmdIn)
 {
     // should got replay in form "2 0 KEY_1 event6"
 
-    DEBUG2("isInputLircCommand: >%s<",cmdIn);
+    DEBUG2("[EX]: isInputLircCommand: >%s<",cmdIn);
 
     /*char *f = cmdIn;
     sprintf(tmp, "isLircCommand: DUMP >%c< >%d<",*f,*f);
-        logger("DBG",tmp);
+        logger(L_DBG,tmp);
     */
 
     int isLirc = 1;
@@ -838,7 +849,7 @@ static int isInpLircCommand(char *cmdIn)
     }
 
     if (isLirc) {
-        DEBUG2("isLircCommand: one commmand >%s<", data);
+        DEBUG2("[EX]: isLircCommand: one commmand >%s<", data);
         handle_key_press(data,1);
     }
 
@@ -861,9 +872,9 @@ static int isIViewerCommand(char *cmdIn)
     // p=value\3
     // sXX=value\3
 
-    DEBUG2("isIViewerCommand: >%s<",cmdIn);
+    DEBUG2("[EX]: isIViewerCommand: >%s<",cmdIn);
 
-    char* cmdTmp = calloc(strlen(cmdIn) + 1, sizeof(char));
+    char* cmdTmp = (char*) calloc(strlen(cmdIn) + 1, sizeof(char));
     strcpy(cmdTmp,cmdIn);
 
     if (!((cmdTmp[0] == 'a' && isdigit(cmdTmp[1])) ||
@@ -887,9 +898,9 @@ static int isIViewerCommand(char *cmdIn)
     }
     token = strtok_r(NULL,"=",&bufPtr);
 
-    DEBUG2("isIViewerCommand: OK >%d<", (int) strlen(cmdIn) + 6);
+    DEBUG2("[EX]: isIViewerCommand: OK >%d<", (int) strlen(cmdIn) + 6);
 
-    char* cmd = calloc(strlen(cmdIn) + 6, sizeof(char));
+    char* cmd = (char*) calloc(strlen(cmdIn) + 6, sizeof(char));
     strcpy(cmd,cmdTmp);
 
     strcat(cmd,"(");
@@ -911,10 +922,10 @@ static int isIViewerCommand(char *cmdIn)
     }
     free(cmdTmp);
 
-    DEBUG2("isIViewerCommand: one commmand >%s<", cmd);
+    DEBUG2("[EX]: isIViewerCommand: one commmand >%s<", cmd);
     handle_key_press(cmd,1);
 
-    logger("INF", "isIViewerCommand: EXIT");
+    logger(L_INF, "[EX]: isIViewerCommand: EXIT");
     free(cmd);
     return 1;
 }
