@@ -2,8 +2,8 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
-// 
+// Copyright (C) 2006-2012 Mikhail Fedotov <anyremote@mail.ru>
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
@@ -13,10 +13,10 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
 #ifndef _EXECUTOR_H_
@@ -32,10 +32,9 @@
 
 #define EM_AS_IS 	99
 
-typedef struct em
-{
-	int        type;
-        void*      value;
+typedef struct em {
+    int        type;
+    void*      value;
 } eMessage;
 
 gpointer executorRoutine	(gpointer thread);
