@@ -34,7 +34,7 @@
 #define REGEX_CMDBYCMD "[[:space:]]*(Exec|ExecAndSet|Make|Get|Set|Send|ExecAndSend|Timer|Macro|Load|Include|SendCKPD|Emulate|Dbus)[[:space:]]*(\\()|[[:space:]]*(Exit)[[:space:]]*;{0,1}"
 
 #define REGEX_SET    "[[:space:]]*(bg|editfield|filemanager|fg|font|fullscreen|icons|list|iconlist|menu|parameter|skin|status|text|title|volume|image|cover|popup)[[:space:]]*,[[:space:]]*(.*)|[[:space:]]*(vibrate|repaint|disconnect)[[:space:]]*"
-#define REGEX_GET    "[[:space:]]*(screen_size|cover_size|model|version|cursor|ping|password)[[:space:]]*|[[:space:]]*(is_exists)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*"
+#define REGEX_GET    "[[:space:]]*(screen_size|cover_size|icon_size|icon_padding|model|version|cursor|ping|password)[[:space:]]*|[[:space:]]*(is_exists)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*"
 #define REGEX_TIMER  "[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*,[[:space:]]*([[:digit:]]*)[[:space:]]*$|[[:space:]]*([^[:space:]]+)[[:space:]]*,[[:space:]]*(cancel|pause|reset|restart|continue)"
 #define REGEX_MAKE   "[[:space:]]*(remote|mode|var|alarm)[[:space:]]*,[[:space:]]*(.*)[[:space:]]*|[[:space:]]*(exit|flush|stop|disconnect|none)[[:space:]]*"
 
@@ -67,12 +67,12 @@ CONF conf = { MODEL_DEFAULT,	// Model
               0
             };        	// set gid
 
-type_key* findExact(mode *mode, char *key)
+type_key* findExact(mode *mode, const char *key)
 {
-    //logger("DBG", "findExact()");
+    //logger(L_DBG, "findExact()");
 
     if (mode == NULL || key == NULL) {
-        logger("DBG", "findExact() input is empty ?");
+        logger(L_DBG, "findExact() input is empty ?");
         return NULL;
     }
     type_key* It = mode->keys;
@@ -80,12 +80,12 @@ type_key* findExact(mode *mode, char *key)
     // Search exact command
     while (It != NULL && It->key != NULL && strcmp(It->key,key) != 0) {
         //sprintf(tmp,"findExact search >%s< compare to >%s<", It->key, key);
-        //logger("DBG",tmp);
+        //logger(L_DBG,tmp);
 
         It = (type_key*) It->next;
-        //logger("DBG", "findExact() next loop");
+        //logger(L_DBG, "findExact() next loop");
     }
-    //logger("DBG", "findExact() exiting");
+    //logger(L_DBG, "findExact() exiting");
     return It;
 }
 
@@ -104,7 +104,7 @@ mode* findMode(const char *name)
 void setMode (const char *modeName)
 {
     if (modeName ==  NULL) {
-        logger("DBG", "setMode() NULL input");
+        logger(L_DBG, "setMode() NULL input");
         return;
     }
     DEBUG2("setMode() to %s", modeName);
@@ -115,7 +115,7 @@ void setMode (const char *modeName)
         currentMode = mp;
         DEBUG2("setMode() new mode was set to %s", currentMode->name);
     } else {
-        logger("DBG", "setMode() new mode did not found");
+        logger(L_DBG, "setMode() new mode did not found");
     }
 
     return;
@@ -138,7 +138,7 @@ static void setCfgDir(char *d)
 
     if (d != NULL) {	// search ../Utils directory
 
-        char* try2 = malloc(strlen(d) + 10); // + "/../Utils"
+        char* try2 = (char*) malloc(strlen(d) + 10); // + "/../Utils"
         strcpy(try2,d);
         strcat(try2,"/../Utils");
 
@@ -157,11 +157,11 @@ static void setCfgDir(char *d)
 
     // last resort: use {prefix}/anyremote/cfg-data directory
 #ifdef DATADIR
-    conf.cfgDir = malloc(strlen(DATADIR)+20);	// + "/anyremote/cfg-data"
+    conf.cfgDir = (char*) malloc(strlen(DATADIR)+20);	// + "/anyremote/cfg-data"
     strcpy(conf.cfgDir,DATADIR);
     strcat(conf.cfgDir,"/anyremote/cfg-data");
 #else
-    conf.cfgDir = malloc(2);
+    conf.cfgDir = (char*) malloc(2);
     strcpy(conf.cfgDir,".");
 #endif
 
@@ -202,7 +202,7 @@ int parse_opts(int argc, char *argv[])
     return 1;
 }
 
-static void regexpPrepare(regex_t *r, char *p)
+static void regexpPrepare(regex_t *r, const char *p)
 {
     int err_no=0;
 
@@ -210,7 +210,7 @@ static void regexpPrepare(regex_t *r, char *p)
         size_t length;
         char *buffer;
         length = regerror (err_no, r, NULL, 0);
-        buffer = malloc(length);
+        buffer = (char*) malloc(length);
         regerror (err_no, r, buffer, length);
         printf("regexpPrepare(): regcomp() error %s", buffer);
 
@@ -360,7 +360,7 @@ static int parseKeyValue(char *in, char ** tag, char ** value)
     return EXIT_OK;
 }
 
-char* id2Cmd (int cmdId)
+const char* id2Cmd (int cmdId)
 {
     switch(cmdId) {
     case ID_EXIT:
@@ -477,7 +477,7 @@ static int storeGetCmd(cmdItem* ci, char *cmd)
 
     regmatch_t* result = allocRegmatch(no_sub);
 
-    if (regexec(regex, cmd, no_sub, result, 0) == 0) {	// screen_size, cover_size, model
+    if (regexec(regex, cmd, no_sub, result, 0) == 0) {	// screen_size, cover_size, icon_size, icon_padding, model
         if (result[1].rm_so >= 0) {
             ci->descr = (char*) calloc(1, result[1].rm_eo - result[1].rm_so + 1);
             strncpy(ci->descr, cmd + result[1].rm_so, result[1].rm_eo - result[1].rm_so);
@@ -597,7 +597,7 @@ static int storeMakeCmd(cmdItem* ci, char *cmd)
                     //printf ("storeMakeCmd: (3) %s %s \n",ci->descr,ci->exec);
 
                 } else {
-                    printf("storeMakeCmd(): parse error: invalide parameter in Set(remote,...)\n");
+                    printf("storeMakeCmd(): parse error: invalid parameter in Make(remote,...)\n");
                     parseFail = 1;
                 }
             } else {
@@ -647,12 +647,12 @@ static void storeMacroCmd(cmdItem* ci, char *cmd)
     // Why ?
     //deleteSpaces(&cmd,0);
 
-    char *dsc = calloc(1, strlen(cmd) + 1);
+    char *dsc = (char*) calloc(1, strlen(cmd) + 1);
     strcpy(dsc, cmd);
     ci->descr = dsc;
 
     if (comma && *comma != '\0') {
-        char *ex = calloc(1, strlen(comma) + 1);
+        char *ex = (char*) calloc(1, strlen(comma) + 1);
         strcpy(ex, comma);
         ci->exec = ex;
     }
@@ -1189,7 +1189,7 @@ int storeCmds(cmdItem** cmdList, char *value)
 
         int cmdIsOk = EXIT_OK;
         // Insert into command list
-        cmdItem* newCmd = calloc(1, sizeof(cmdItem));
+        cmdItem* newCmd = (cmdItem*) calloc(1, sizeof(cmdItem));
 
         newCmd->type = cmdId;
         newCmd->next = NULL;
@@ -1203,7 +1203,7 @@ int storeCmds(cmdItem** cmdList, char *value)
             } else if (cmdId == ID_TIMER) {
                 cmdIsOk = storeTimerCmd(newCmd,cmds);
             } else if (cmdId == ID_EXEC) {
-                char *newDescr = calloc(1, strlen(cmds) + 1);
+                char *newDescr = (char*) calloc(1, strlen(cmds) + 1);
                 strcpy(newDescr, cmds);
                 newCmd->exec = newDescr;
             } else if (cmdId == ID_GET) {
@@ -1219,8 +1219,8 @@ int storeCmds(cmdItem** cmdList, char *value)
                     cmdIsOk = EXIT_NOK;
                 } else {
 
-                    char *dsc = calloc(1, comma - cmds + 1);
-                    char *exc = calloc(1, strlen(comma));
+                    char *dsc = (char*) calloc(1, comma - cmds + 1);
+                    char *exc = (char*) calloc(1, strlen(comma));
                     strncpy(dsc, cmds, comma - cmds);
                     strcpy(exc, comma + 1);
                     newCmd->descr = dsc;
@@ -1232,7 +1232,7 @@ int storeCmds(cmdItem** cmdList, char *value)
                 } else if (cmdId != ID_SEND) {
                     deleteSpaces(&cmds,0);
                 }
-                char *newDescr = calloc(1, strlen(cmds) + 1);
+                char *newDescr = (char*) calloc(1, strlen(cmds) + 1);
                 strcpy(newDescr, cmds);
                 newCmd->descr = newDescr;
             }
@@ -1264,7 +1264,7 @@ int storeCmds(cmdItem** cmdList, char *value)
 static int storeKey(mode* cMode, type_key **head, char *tag, char *value)
 {
     type_key* It = NULL;
-    int ret;
+    int ret = EXIT_OK;
 
     //printf("storeKey\n");
 
@@ -1307,7 +1307,7 @@ static int storeKey(mode* cMode, type_key **head, char *tag, char *value)
         It->cmd = NULL;
     }
 
-    return EXIT_OK;
+    return ret;
 }
 
 static char* loadLine(FILE *fp)
@@ -1348,7 +1348,7 @@ static int loadKeys(FILE *fp)
         currentMode   = defMode;
     }
 
-    mode *curMode = currentMode;
+    mode *curMode = findMode("default");
     do {
         //printf("loadKeys -------------------------------------------------------------------------\n");
         tmptext=loadLine(fp);
@@ -1519,13 +1519,9 @@ void freeRegexps()
     }
 }
 
-int init_cfg(char *path)
+void init_cfg_dir(char *path)
 {
-    int ret = EXIT_OK;
-
     if (path != NULL) {
-
-        printf("Use configuration file %s\n",path);
         char *d = strdup(path);
         char *p = rindex(d,SEPARATOR);
         if (p != NULL) {
@@ -1535,10 +1531,22 @@ int init_cfg(char *path)
         }
         setCfgDir(d);
         free(d);
-
-        ret = load_cfg(path,1);
     } else {
         setCfgDir(NULL);
+    }
+}
+
+int init_cfg(char *path)
+{
+    //printf("init_cfg %s\n",path);
+    int ret = EXIT_OK;
+
+    if (path != NULL) {
+
+        printf("Use configuration file %s\n",path);
+        ret = load_cfg(path,1);
+   
+    } else {
 
         char cfgfile[MAXLEN];
         strcpy(cfgfile, getenv("HOME"));
