@@ -33,9 +33,6 @@
 #define MAXNAMELEN   	512
 #define MAXCMDLEN   	1024
 
-//#define DEFAULT_DEVICE  "/dev/rfcomm0"	seems JSR-82 phones is more usable now
-#define DEFAULT_DEVICE  "bluetooth:19"
-
 #define KEYS_SECTION_STR     "[Keys]"
 #define PROTOCOL_SECTION_STR "[Protocol]"
 #define MODE_END_STR         "[ModeEnd]"
@@ -240,7 +237,8 @@ typedef struct Ta {
 
 // Exported functions definitions
 
-char* id2Cmd            (int cmdId);
+const char* id2Cmd      (int cmdId);
+void  init_cfg_dir      (char *path);
 int   init_cfg          (char *path);
 void  freeRegexps       (void);
 int   parse_opts        (int argc, char *argv[]);
