@@ -59,7 +59,7 @@ int connectFrontEnd(int portno)
 {
     int flags;
     sprintf(tmp, "connect to frontend >%d<",portno );
-    logger("DBG", tmp);
+    logger(L_DBG, tmp);
 
     struct sockaddr_in serv_addr;
     struct hostent     *server;
@@ -69,7 +69,7 @@ int connectFrontEnd(int portno)
     }
     sockfd_fe = socket(AF_INET, SOCK_STREAM|SOCK_CLOEXEC, 0);
     if (sockfd_fe < 0) {
-        logger("ERR", "opening socket for frontend");
+        logger(L_ERR, "opening socket for frontend");
         return EXIT_NOK;
     }
 
@@ -91,7 +91,7 @@ int connectFrontEnd(int portno)
     int ret = connect(sockfd_fe,(const struct sockaddr *) &serv_addr, sizeof(serv_addr));
     if (ret != 0 && errno != EINPROGRESS) {
         sprintf(tmp, "connect socket for frontend (%d) errno = %d", ret, errno);
-        logger("ERR", tmp);
+        logger(L_ERR, tmp);
         return EXIT_NOK;
     }
 
@@ -107,23 +107,23 @@ void disconnectFrontEnd()
     return;
 }
 
-void writeToFrontEnd(char *buf)
+void writeToFrontEnd(const char *buf)
 {
     int n = write(sockfd_fe, buf,strlen(buf));
     if (n < 0) {
-        logger("ERR", "ERROR writing to frontend");
+        logger(L_ERR, "ERROR writing to frontend");
     }
     return;
 }
 
-void sendToFrontEnd(char *buf)
+void sendToFrontEnd(const char *buf)
 {
     if (q2fe == NULL || sockfd_fe <= 0 || buf == NULL) {
         return;
     }
 
     sprintf(tmp, "send to frontend >%s<", buf);
-    logger("DBG", tmp);
+    logger(L_DBG, tmp);
 
     g_async_queue_push(q2fe,strdup(buf));
 
@@ -132,7 +132,7 @@ void sendToFrontEnd(char *buf)
 
 int readFromFrontEnd(char *buf, int size)
 {
-    //logger("INF", "readFromFrontEnd");
+    //logger(L_INF, "readFromFrontEnd");
     if (buf == NULL) {
         return EXIT_OK;
     }
@@ -140,13 +140,13 @@ int readFromFrontEnd(char *buf, int size)
     bzero(buf,size);
     int n = read(sockfd_fe,buf,size-1);
     if (n < 0) {
-        //logger("ERR", "ERROR reading from socket");
+        //logger(L_ERR, "ERROR reading from socket");
         return EXIT_NOK;
     } else {
         *(buf+n) = '\0';
         if (n > 0) {
             sprintf(tmp, "Got from frontend (%d) >%s<", n, buf);
-            logger("DBG", tmp);
+            logger(L_DBG, tmp);
 
             int i = 0;
             int k = 0;
@@ -160,7 +160,7 @@ int readFromFrontEnd(char *buf, int size)
             }
             *(buf+k) = '\0';
             sprintf(tmp, "Got from frontend (%d) >%s<", n, buf);
-            logger("DBG", tmp);
+            logger(L_DBG, tmp);
         }
     }
 
@@ -177,13 +177,13 @@ gboolean frontendRoutine(gpointer data)
         } else {
             if (isFirst) {
                 isFirst = 0;
-                logger("INF","Do not start front end thread");
+                logger(L_INF,"Do not start front end thread");
             }
             return FALSE;
         }
 
         if  (ret == EXIT_OK) {
-            logger("INF","Start listening to frontend");
+            logger(L_INF,"Start listening to frontend");
         } else {
             return TRUE;
         }
@@ -195,7 +195,7 @@ gboolean frontendRoutine(gpointer data)
         if (frontEndBuf[0] != '\0') {
             DEBUG2("readFromFrontEnd() >%s<", frontEndBuf);
 
-            eMessage* em = malloc(sizeof(eMessage));
+            eMessage* em = (eMessage*) malloc(sizeof(eMessage));
             em->type  = EM_STRING;
             em->value = strdup(frontEndBuf);
 
