@@ -26,8 +26,8 @@
 // Frontend support
 gboolean frontendRoutine(gpointer data);
 int   connectFrontEnd	(int portno);
-void  sendToFrontEnd	(char *buf);
+void  sendToFrontEnd	(const char *buf);
 void  disconnectFrontEnd(void);
-int   readFromFrontEnd	(char *buf, int size);
+int   readFromFrontEnd	(const char *buf, int size);
 
 #endif
