@@ -223,8 +223,8 @@ int closeL2capPort(int final)
         close(sportfd);
         sportfd = 0;
     }
-
-    if (finale) {
+    
+    if (final) {
         sdpDeregisterL2cap();
     }
     return 1;
