@@ -101,25 +101,28 @@ void initLog()
             fclose(fplog);
         }
         if(getuid()==0 && conf.uid) { // do not open file as superuser
-            chown(logfile,conf.uid,conf.gid);
+            #ifdef __cplusplus
+	    int dummy = 
+	    #endif
+	        chown(logfile,conf.uid,conf.gid);
         }
 
         logMutex = g_mutex_new();
         
 	printTime();
         sprintf(tmp, "anyRemote v%s", PACKAGE_VERSION);
-	logger("CFG", tmp);
+	logger(L_CFG, tmp);
     }
 }
 
-void logger(char *head, char *str)
+static void logger2(const char *head, const char *str)
 {
     //printf("logger ENTER\n");fflush(stdout);
     FILE *fplog;
     time_t logtime;
 
     if (logfile[0] == '\0' ||
-            (!getLog())        ||
+            (!getLog())    ||
             (strcmp(head, "DBG") == 0 && getDebug() == 0)) {
         return;
     }
@@ -144,13 +147,36 @@ void logger(char *head, char *str)
 
         fclose(fplog);
     } else {
-        printf("Can't open log file >%s<\n", logfile);
+        printf("Can not open log file >%s<\n", logfile);
+	logfile[0] = '\0';  // print this error only once
     }
 
     g_mutex_unlock(logMutex);
     //printf("logger EXIT\n");fflush(stdout);
 }
 
+void logger(int head, const char *str)
+{
+    switch (head) {
+        case L_CFG:
+	    logger2("CFG", str);
+	    break;
+	case L_INF:
+	    logger2("INF", str);
+	    break;
+	case L_WARN:
+	    logger2("WARNING", str);
+	    break;
+        case L_ERR:
+	    logger2("ERR", str);
+	    break;
+	//case L_DBG:
+	default:
+	    logger2("DBG", str);
+	    break;
+    }
+}
+
 void printTime()
 {
     time_t logtime;
@@ -158,7 +184,7 @@ void printTime()
 
     char *timestr = (char *) ctime(&logtime);
     timestr[strlen(timestr)-1]=0;
-    logger("CFG", timestr);
+    logger(L_CFG, timestr);
 }
 void setCmdFiles()
 {
@@ -204,19 +230,19 @@ timerCmd* createTimer(cmdItem *ci)
 {
     //printf("createTimer\n");
     if (ci->descr == NULL || ci->descr[0] == '\0' || ci->tdata == NULL) {
-        logger("DBG", "createTimer(): wrong input");
+        logger(L_DBG, "createTimer(): wrong input");
         return NULL;
     }
     //printf("createTimer %s\n", ci->descr);
     if (findTimer(ci->descr, NULL) != NULL) {
-        logger("DBG", "createTimer(): timer already exists");
+        logger(L_DBG, "createTimer(): timer already exists");
         return NULL;
     }
-    timerCmd *tm = calloc(1,sizeof(timerCmd));
+    timerCmd *tm = (timerCmd *) calloc(1,sizeof(timerCmd));
 
     tm->ticks     = 0;
     tm->times     = 1;
-    cmdItem* dup  = calloc(1, sizeof(cmdItem));
+    cmdItem* dup  = (cmdItem*) calloc(1, sizeof(cmdItem));
 
     dup->type  = ci->type;
     dup->descr = (char*) calloc(1, strlen(ci->descr)+1);
@@ -252,7 +278,7 @@ void cancelTimer(char *id)
     timerCmd *prev = NULL;
     timerCmd *tm = findTimer(id, (timerCmd **) &prev);
     if (tm == NULL) {
-        logger("DBG", "Can not find timer to cancel!");
+        logger(L_DBG, "Can not find timer to cancel!");
         return ;
     }
 
@@ -270,7 +296,7 @@ static void deleteTimer(char *id)
     timerCmd *prev = NULL;
     timerCmd *tm = findTimer(id, (timerCmd **) &prev);
     if (tm == NULL) {
-        logger("DBG", "Can not find timer to delete!");
+        logger(L_DBG, "Can not find timer to delete!");
         return ;
     }
     if (tm == timers) { //remove in head
@@ -279,7 +305,7 @@ static void deleteTimer(char *id)
         if (prev != NULL) {
             prev->next = tm->next;
         } else {
-            logger("ERR", "Previous item absent for non-first element");
+            logger(L_ERR, "Previous item absent for non-first element");
             return;
         }
     }
@@ -293,7 +319,7 @@ static void deleteTimer(char *id)
 
 void freeTimers()
 {
-    logger("DBG", "freeTimers()");
+    logger(L_DBG, "freeTimers()");
     timerCmd *tm;
 
     while (timers != NULL) {
@@ -305,32 +331,32 @@ void freeTimers()
     }
 }
 
-extern void macroCmd(char *macro, cmdParams* params);
+extern int macroCmd(char *descr, char *exec, cmdParams* params);
 
-void verifyTimers(int ticksInSec)
+void verifyTimerCfg(int ticksInSec)
 {
-    //logger("DBG", "verifyTimers()");
+    //logger(L_DBG, "verifyTimerCfg()");
     timerCmd *tm = timers;
 
     while (tm != NULL) {
         timerCmd *tm_next = tm->next;
 
         if (tm->status == TIMER_RUN) {	// do not process paused timers
-            //DEBUG2("verifyTimers(): timer %p\n",tm);
-            //DEBUG2("verifyTimers(): timer descr %s ", tm->timer->descr);
-            //DEBUG2("verifyTimers(): timer ticks %d ", tm->ticks);
-            //DEBUG2("verifyTimers(): timer tmout %d ", tm->timer->tdata->timeout);
+            //DEBUG2("verifyTimerCfg(): timer %p\n",tm);
+            //DEBUG2("verifyTimerCfg(): timer descr %s ", tm->timer->descr);
+            //DEBUG2("verifyTimerCfg(): timer ticks %d ", tm->ticks);
+            //DEBUG2("verifyTimerCfg(): timer tmout %d ", tm->timer->tdata->timeout);
             if (tm->ticks >= (tm->timer->tdata->timeout * ticksInSec)) {
-                DEBUG2("verifyTimers(): it is time to execute %s", tm->timer->descr);
+                DEBUG2("verifyTimerCfg(): it is time to execute %s", tm->timer->descr);
 
-                macroCmd(tm->timer->descr,NULL);
+                macroCmd(tm->timer->descr, tm->timer->exec, NULL);
 
                 tm->ticks = 0;
 
                 if (tm->timer->tdata->times > 0) {
                     tm->times++;
                     if (tm->times >= tm->timer->tdata->times) {    // Cancel this timer
-                        DEBUG2("verifyTimers(): timer %s self-canceled", tm->timer->descr);
+                        DEBUG2("verifyTimerCfg(): timer %s self-canceled", tm->timer->descr);
                         cancelTimer(tm->timer->descr);
                     }
                 }
@@ -371,7 +397,7 @@ int isDataNew(int what, char *data, int size)
     }
 
     if (isNew == EXIT_OK) {
-        lastValues[what] = calloc(size + 1, 1);
+        lastValues[what] = (char*) calloc(size + 1, 1);
         memcpy(lastValues[what],data,size);
         lastValuesSize[what] = size;
     }
@@ -380,6 +406,7 @@ int isDataNew(int what, char *data, int size)
 
 void freeCachedData()
 {
+    //DEBUG2("freeCachedData()");
     int i = 0;
     for (; i<ID_SETMAX; i++) {
         if (lastValues[i] != NULL) {
@@ -405,7 +432,7 @@ varData* searchVar(const char *id, int len)
     strcpy(tmp, "searchVar() >");
     strncat(tmp,id,len);
     strcat(tmp,"<");
-    logger("DBG", tmp);*/
+    logger(L_DBG, tmp);*/
 
     varData* ptr = vars;
 
@@ -415,6 +442,22 @@ varData* searchVar(const char *id, int len)
     return ptr;
 }
 
+const char* getVarValue(const char *id)
+{
+    if (id == NULL) {
+        return NULL;
+    }
+
+    int sz = strlen(id);
+    
+    varData* ptr = vars;
+
+    while (ptr != NULL && ptr->name != NULL && (strlen(ptr->name) != sz || strncmp(ptr->name,id,sz) != 0)) {
+        ptr  = ptr->next;
+    }
+    return (ptr ? ptr->value : NULL);
+}
+
 static int addVar(const char *name, const char *val, int sz)
 {
     //printf("addVar() >%s< >%s<\n", name?name:"NULL",val?val:"NULL");
@@ -448,7 +491,7 @@ void addInternalVars()
     char *d = getenv("HOME");
     addVar("Home", d, d ? strlen(d) : 0);
 
-    d = getCfgDir();
+    d = getConfigDir();
     addVar("CfgDir", d, d ? strlen(d) : 0);
 
 #ifdef USE_XTEST
@@ -479,7 +522,7 @@ void addInternalVars()
     addVar(CHARSET_STR,    "8859-1", 6);			// AT mode only
     addVar("CmerOff",      "",       0);	   		// AT mode only
     addVar("CmerOn",       "",       0);			// AT mode only
-    addVar("Device",       "bluetooth:19", 12);
+    addVar("Device",       DEFAULT_DEVICE, 12);
     addVar("Logging",      "false",  5);
     addVar("RetrySeconds", "60",     2);
     addVar("ServiceName",  "anyRemote",    10);
@@ -492,7 +535,7 @@ void addInternalVars()
 void printVars()
 {
     sprintf(tmp, "[Variables]");
-    logger("CFG", tmp);
+    logger(L_CFG, tmp);
 
     varData* ptr = vars;
     while (ptr != NULL) {
@@ -501,12 +544,12 @@ void printVars()
         memset(tmp, 0, MAXMAXLEN);
         sprintf(tmp, "\t%s \t-> ", ptr->name);
         strncat(tmp, ptr->value != NULL ? ptr->value : "(empty)",ptr->value != NULL ? ptr->size : 7);
-        logger("CFG", tmp);
+        logger(L_CFG, tmp);
 
         ptr  = ptr->next;
     }
     sprintf(tmp, "[End]");
-    logger("CFG", tmp);
+    logger(L_CFG, tmp);
 }
 
 // can be used only to _string_ data
@@ -552,7 +595,7 @@ int setVar(const char *name, const char *val, int sz)
 
 void freeVars()
 {
-    //logger("DBG", "freeVars()");
+    //logger(L_DBG, "freeVars()");
     varData *vv;
 
     while (vars != NULL) {
@@ -593,6 +636,7 @@ void printHelp()
     printf(" -s connect string,  possible values\n");
     printf("    bluetooth:<channel> (Server mode - bluetooth connection)\n");
     printf("    socket:<port>       (Server mode - TCP/IP connection)\n");
+    printf("    web:<port>          (Server mode - Web interface)\n");
     printf("    local:/dev/ircommX  (Server mode - IR connection)\n");
     printf("    rfcomm:XX:XX:XX:XX:XX:XX:CC (AT mode - bluetooth connection,\n");
     printf("        where XX:XX:XX:XX:XX:XX is bluetooth device address,\n");
@@ -604,7 +648,6 @@ void printHelp()
     printf(" -log	print verbose logging information to $HOME/.anyRemote/anyremote.log\n");
     printf(" -a	reconnect automatically in case of connection failure\n");
     printf(" -fe <port> work as backend for GUI frontend. Use specified port to connect to frontend.\n");
-    printf(" -http  tune work with anyremote2html\n");
     printf(" -name <SDP service name> if bluetooth connection is used, allows to specify SDP service name\n");
     printf(" -password ask password on connect\n");
     printf("           password should be stored in $HOME/.anyRemote/password file in plain text\n");
@@ -619,7 +662,7 @@ void printHelp()
 
 int flushData()
 {
-    //logger("DBG","flushData");
+    //logger(L_DBG,"flushData");
 
     flushConf = 1;
 
@@ -672,7 +715,7 @@ char* getStoredPass()
         return NULL;
     }
 
-    char* resfile = calloc(strlen(h)+21,1);
+    char* resfile = (char*) calloc(strlen(h)+21,1);
 
     strcpy(resfile, h);
     strcat(resfile, "/.anyRemote/password");
@@ -692,8 +735,12 @@ char* getStoredPass()
         return NULL;
     }
 
-    char * fBuffer = calloc(fLen+1,1);
-    fread(fBuffer, sizeof(char), fLen, fp);
+    char * fBuffer = (char*) calloc(fLen+1,1);
+    #ifdef __cplusplus
+    size_t dummy = 
+    #endif
+        fread(fBuffer, sizeof(char), fLen, fp);
+    
     fclose(fp);
 
     // strinp \n from the end
@@ -718,14 +765,14 @@ static void sendToMainThread(int *m)
 
 void sendAbort()
 {
-    int* i = malloc(sizeof(int));
+    int* i = (int*) malloc(sizeof(int));
     *i = M_ABORT;
     sendToMainThread(i);
 }
 
 void sendDisconnect()
 {
-    int* i = malloc(sizeof(int));
+    int* i = (int*) malloc(sizeof(int));
     *i = M_DISCONNECT;
     sendToMainThread(i);
 }
