@@ -32,11 +32,19 @@
 #define TIMER_PAUSE     2
 #define TIMER_CANCEL    3
 
-#define CFG2(...)     sprintf(tmp,__VA_ARGS__);logger("CFG", tmp);
-#define DEBUG2(...)   sprintf(tmp,__VA_ARGS__);logger("DBG", tmp);
-#define ERROR2(...)   sprintf(tmp,__VA_ARGS__);logger("ERR", tmp);
-#define INFO2(...)    sprintf(tmp,__VA_ARGS__);logger("INF", tmp);
-#define WARNING2(...) sprintf(tmp,__VA_ARGS__);logger("WRN", tmp);
+enum LogType {
+    L_CFG = 0,
+    L_INF,
+    L_DBG,
+    L_WARN,
+    L_ERR
+};
+
+#define CFG2(...)     sprintf(tmp,__VA_ARGS__);logger(L_CFG,  tmp);
+#define DEBUG2(...)   sprintf(tmp,__VA_ARGS__);logger(L_DBG,  tmp);
+#define ERROR2(...)   sprintf(tmp,__VA_ARGS__);logger(L_ERR,  tmp);
+#define INFO2(...)    sprintf(tmp,__VA_ARGS__);logger(L_INF,  tmp);
+#define WARNING2(...) sprintf(tmp,__VA_ARGS__);logger(L_WARN, tmp);
 
 #define M_ABORT 	0
 #define M_DISCONNECT 	1
@@ -64,11 +72,12 @@ void        printHelp       (void);
 void        printTime       (void);
 void        printVars       (void);
 void        initLog         (void);
-void        logger          (char *head, char *str);
+void        logger          (int head, const char *str);
+//void        logger          (const char *head, const char *str);
 
 timerCmd*   createTimer     (cmdItem *ci);
 timerCmd*   findTimer       (char *id, timerCmd **prev);
-void        verifyTimers    (int ticksInSec);
+void        verifyTimerCfg  (int ticksInSec);
 void        cancelTimer     (char *id);
 void        freeTimers      (void);
 
@@ -76,6 +85,7 @@ int         setVarSimple    (const char *name, const char *val);
 int         setVar          (const char *name, const char *val, int size);
 varData*    searchVar       (const char *id, int len);
 void        freeVars        (void);
+const char*  getVarValue    (const char *name);
 
 int         isDataNew       (int what, char *data, int size);
 void        freeCachedData  (void);
